<?php
/**
 * Siteorigin Panels Compatibility File
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Registers custom builder.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_widget
 */
function mymedic_builders_init() {

	// Tabs block
	require trailingslashit( get_template_directory() ) . 'inc/builder/tabs.php';
	register_widget( 'MyMedic_Tabs_Block' );

	// Doctor Grid block
	require trailingslashit( get_template_directory() ) . 'inc/builder/doctor-grid.php';
	register_widget( 'MyMedic_Doctor_Grid_Block' );

	// Doctor Carousel block
	require trailingslashit( get_template_directory() ) . 'inc/builder/doctor-carousel.php';
	register_widget( 'MyMedic_Doctor_Carousel_Block' );

	// Portfolio block
	require trailingslashit( get_template_directory() ) . 'inc/builder/portfolio.php';
	register_widget( 'MyMedic_Portfolio_Block' );

	// Feature block
	require trailingslashit( get_template_directory() ) . 'inc/builder/feature.php';
	register_widget( 'MyMedic_Feature_Block' );

	// Feature with Big Image block
	require trailingslashit( get_template_directory() ) . 'inc/builder/image.php';
	register_widget( 'MyMedic_Image_Block' );

	// Custom Content block
	require trailingslashit( get_template_directory() ) . 'inc/builder/custom-content.php';
	register_widget( 'MyMedic_Custom_Content_Block' );

	// Number block
	require trailingslashit( get_template_directory() ) . 'inc/builder/number.php';
	register_widget( 'MyMedic_Number_Block' );

	// Testimonial block
	require trailingslashit( get_template_directory() ) . 'inc/builder/testimonial.php';
	register_widget( 'MyMedic_Testimonial_Block' );

	// Blog block
	require trailingslashit( get_template_directory() ) . 'inc/builder/blog.php';
	register_widget( 'MyMedic_Blog_Block' );

}
add_action( 'widgets_init', 'mymedic_builders_init' );

/**
 * Add new panel
 *
 * @since 1.0.0
 */
function mymedic_panels_add_widgets_dialog_tabs( $tabs ){

	$tabs[] = array(
		'title'  => esc_html__( 'MyMedic Widgets', 'mymedic' ),
		'filter' => array(
			'installed' => true,
			'groups'    => array( 'mymedic' )
		)
	);

	return $tabs;
}
add_filter( 'siteorigin_panels_widget_dialog_tabs', 'mymedic_panels_add_widgets_dialog_tabs' );

/**
 * Set the groups for all Roku Widgets
 *
 * @since 1.0.0
 */
function mymedic_panels_add_widget_groups( $widgets ){
	$widgets['MyMedic_Tabs_Block']['groups'] = array( 'mymedic' );
	$widgets['MyMedic_Doctor_Grid_Block']['groups'] = array( 'mymedic' );
	$widgets['MyMedic_Doctor_Carousel_Block']['groups'] = array( 'mymedic' );
	$widgets['MyMedic_Portfolio_Block']['groups'] = array( 'mymedic' );
	$widgets['MyMedic_Feature_Block']['groups'] = array( 'mymedic' );
	$widgets['MyMedic_Image_Block']['groups'] = array( 'mymedic' );
	$widgets['MyMedic_Custom_Content_Block']['groups'] = array( 'mymedic' );
	$widgets['MyMedic_Number_Block']['groups'] = array( 'mymedic' );
	$widgets['MyMedic_Testimonial_Block']['groups'] = array( 'mymedic' );
	$widgets['MyMedic_Blog_Block']['groups'] = array( 'mymedic' );
	return $widgets;
}
add_filter( 'siteorigin_panels_widgets', 'mymedic_panels_add_widget_groups' );

/**
 * Change the margin bottom between block.
 *
 * @since 1.0.0
 */
function mymedic_panels_margin_bottom( $panels_margin_bottom ) {
	$panels_margin_bottom = '0';
	return $panels_margin_bottom;
}
add_filter( 'siteorigin_panels_css_row_margin_bottom', 'mymedic_panels_margin_bottom', 10, 2 );
// add_filter( 'siteorigin_panels_css_row_gutter', 'mymedic_panels_margin_bottom', 10, 2 );

/**
 * Filter the widget output
 *
 * @since 1.0.0
 */
function mymedic_panels_widget_args( $args ) {
	$args['before_title'] = '<h3 class="widget-title">';
	$args['after_title']  = '</h3>';
	return $args;
}
// add_filter( 'siteorigin_panels_widget_args', 'mymedic_panels_widget_args' );

/**
 * Remove 'widget' class
 */
function mymedic_remove_widget_class( $class ) {
	$class = array_diff( $class, array( 'widget' ) );
	return $class;
}
// add_filter( 'siteorigin_panels_widget_classes', 'mymedic_remove_widget_class' );

/**
 * Adds default page layouts
 *
 * @since 1.0.0
 */
function mymedic_prebuilt_page_layouts( $layouts ) {

	$layouts = array(
		'department' => array (
			'name'        => esc_html__( 'Departments', 'mymedic' ),
			'description' => esc_html__( 'Prebuilt layout for Departments page.', 'mymedic' ),
			'widgets' => array (
				0 => array (
					'title' => '',
					'desc' => '',
					'type' => 'department',
					'order' => 'asc',
					'orderby' => 'rand',
					'panels_info' => array (
						'class' => 'MyMedic_Tabs_Block',
						'grid' => 0,
						'cell' => 0,
						'id' => 0,
					),
				),
			),
			'grids' => array (
				0 => array (
					'cells' => 1,
				),
			),
			'grid_cells' => array (
				0 => array (
					'grid' => 0,
					'weight' => 1,
				),
			),
		),

		'doctor' => array(
			'name'        => esc_html__( 'Doctors', 'mymedic' ),
			'description' => esc_html__( 'Prebuilt layout for Doctors page.', 'mymedic' ),
			'widgets' => array (
				0 => array (
					'title' => '',
					'desc' => '',
					'num' => 0,
					'cat' => 0,
					'order' => 'asc',
					'orderby' => 'rand',
					'overlay' => 0,
					'panels_info' => array (
						'class' => 'MyMedic_Doctor_Carousel_Block',
						'raw' => false,
						'grid' => 0,
						'cell' => 0,
						'id' => 0,
					),
				),
				1 => array (
					'title' => '',
					'desc' => '',
					'num' => 3,
					'cat' => 0,
					'order' => 'desc',
					'orderby' => 'rand',
					'overlay' => 0,
					'panels_info' => array (
						'class' => 'MyMedic_Doctor_Grid_Block',
						'raw' => false,
						'grid' => 1,
						'cell' => 0,
						'id' => 1,
					),
				),
			),
			'grids' => array (
				0 => array (
					'cells' => 1,
				),
				1 => array (
					'cells' => 1,
					'style' => array (
						'class' => 'grey',
					),
				),
			),
			'grid_cells' => array (
				0 => array (
					'grid' => 0,
					'weight' => 1,
				),
				1 => array (
					'grid' => 1,
					'weight' => 1,
				),
			),
		),

		'gallery' => array(
			'name'        => esc_html__( 'Gallery', 'mymedic' ),
			'description' => esc_html__( 'Prebuilt layout for Gallery page.', 'mymedic' ),
			'widgets' => array (
				0 => array (
					'title' => '',
					'desc' => '',
					'num' => 0,
					'order' => 'asc',
					'orderby' => 'name',
					'url' => '',
					'button' => '',
					'overlay' => 0,
					'panels_info' => array (
						'class' => 'MyMedic_Portfolio_Block',
						'grid' => 0,
						'cell' => 0,
						'id' => 0,
					),
				),
			),
			'grids' => array (
				0 => array (
					'cells' => 1,
				),
			),
			'grid_cells' => array (
				0 => array (
					'grid' => 0,
					'weight' => 1,
				),
			),
		),

		'homepage' => array(
			'name'        => esc_html__( 'Home', 'mymedic' ),
			'description' => esc_html__( 'Prebuilt layout for Home page.', 'mymedic' ),
			'widgets' => array (
				0 => array (
					'id' => '2',
					'title' => '',
					'panels_info' => array (
						'class' => 'LayerSlider_Widget',
						'raw' => false,
						'grid' => 0,
						'cell' => 0,
						'id' => 0,
					),
				),
				1 => array (
					'title' => esc_html__( 'Our Departments', 'mymedic' ),
					'desc' => esc_html__( 'Listed below our awesome departments and medical services from our hospital!', 'mymedic' ),
					'num' => 4,
					'type' => 'department',
					'order' => 'desc',
					'orderby' => 'rand',
					'overlay' => 0,
					'panels_info' => array (
						'class' => 'MyMedic_Feature_Block',
						'raw' => false,
						'grid' => 1,
						'cell' => 0,
						'id' => 1,
					),
				),
				2 => array (
					'title' => '',
					'desc' => '',
					'cols' => 'two-one',
					'title_1' => esc_html__( 'Appointment Form', 'mymedic' ),
					'desc_1' => '',
					'shortcode_1' => '[ninja_forms id=10]',
					'title_2' => esc_html__( 'Working Time', 'mymedic' ),
					'desc_2' =>
						'<div class="workingtime">
							<p>Odec adesterc timeam toruatos, matildanos eam debitis examles.Cure sed homerous alienum cu sed homero..</p>
							<hr>
							<ul>
								<li>Monday - Thursday <span>8am - 7pm</span></li>
								<li>Friday <span>8am - 15pm</span></li>
								<li>Saturday <span>10am - 5pm</span></li>
							</ul>
						</div>
						<br><br><hr><br><br><br>
						<div class="general-title text-left">
							<h4>Sundays / Holidays</h4>
							<hr>
						</div>
						<div class="workingtime">
							<p>Odec adesterc timeam toruatos, matildanos eam debitis examles.Cure sed homerous alienum cu sed homero..</p>
							<hr>
							<ul>
								<li>Polyclinic <span>8am - 5pm</span></li>
								<li>Dental <span>9am - 3pm</span></li>
								<li>Pharmacy <span>Closed</span> </li>
							</ul>
						</div>',
					'shortcode_2' => '',
					'title_3' => '',
					'desc_3' => '',
					'shortcode_3' => '',
					'panels_info' => array (
						'class' => 'MyMedic_Custom_Content_Block',
						'grid' => 2,
						'cell' => 0,
						'id' => 2,
					),
				),
				3 => array (
					'title' => esc_html__( 'From Gallery', 'mymedic' ),
					'desc' => esc_html__( 'Listed all our awesome gallery photos!', 'mymedic' ),
					'num' => 6,
					'order' => 'asc',
					'orderby' => 'name',
					'url' => '/gallery',
					'button' => esc_html__( 'View All', 'mymedic' ),
					'overlay' => 0,
					'panels_info' => array (
						'class' => 'MyMedic_Portfolio_Block',
						'raw' => false,
						'grid' => 3,
						'cell' => 0,
						'id' => 3,
					),
				),
				4 => array (
					'title' => '',
					'desc' => '',
					'image' => '',
					'num' => 3,
					'type' => 'service',
					'order' => 'asc',
					'orderby' => 'rand',
					'panels_info' => array (
						'class' => 'MyMedic_Image_Block',
						'raw' => false,
						'grid' => 4,
						'cell' => 0,
						'id' => 4,
					),
				),
				5 => array (
					'title' => esc_html__( 'Our Experienced Doctors', 'mymedic' ),
					'desc' => esc_html__( 'Listed below our professional and experienced hospital personals', 'mymedic' ),
					'num' => 0,
					'cat' => 0,
					'order' => 'asc',
					'orderby' => 'name',
					'overlay' => 0,
					'panels_info' => array (
						'class' => 'MyMedic_Doctor_Carousel_Block',
						'raw' => false,
						'grid' => 5,
						'cell' => 0,
						'id' => 5,
					),
				),
				6 => array (
					'title' => esc_html__( 'MyMedic In Numbers', 'mymedic' ),
					'desc' => esc_html__( 'Listed below our excellent numbers in medical field!', 'mymedic' ),
					'overlay' => 1,
					'icon_1' => 'fa-heartbeat',
					'title_1' => esc_html__( 'Heart Surgery', 'mymedic' ),
					'number_1' => 2210,
					'icon_2' => 'fa-hospital-o',
					'title_2' => esc_html__( 'New Clinic', 'mymedic' ),
					'number_2' => 214,
					'icon_3' => 'fa-h-square',
					'title_3' => esc_html__( '24/7 Emergency', 'mymedic' ),
					'number_3' => 1200,
					'icon_4' => 'fa-hourglass-half',
					'title_4' => esc_html__( 'Fast Service', 'mymedic' ),
					'number_4' => 2312,
					'panels_info' =>
					array (
						'class' => 'MyMedic_Number_Block',
						'raw' => false,
						'grid' => 6,
						'cell' => 0,
						'id' => 6,
					),
				),
				7 =>
				array (
					'title' => esc_html__( 'What Others Say About MyMedic', 'mymedic' ),
					'desc' => esc_html__( 'Listed below relatives of the patient comments, testimonials and clients!', 'mymedic' ),
					'num' => 6,
					'order' => 'asc',
					'orderby' => 'name',
					'overlay' => 0,
					'panels_info' => array (
						'class' => 'MyMedic_Testimonial_Block',
						'raw' => false,
						'grid' => 7,
						'cell' => 0,
						'id' => 7,
					),
				),
				8 => array (
					'title' => esc_html__( 'From the Blog', 'mymedic' ),
					'desc' => esc_html__( 'We shared best articles for health concern', 'mymedic' ),
					'num' => 3,
					'cat' => 0,
					'order' => 'asc',
					'orderby' => 'rand',
					'overlay' => 0,
					'panels_info' => array (
						'class' => 'MyMedic_Blog_Block',
						'raw' => false,
						'grid' => 8,
						'cell' => 0,
						'id' => 8,
					),
				),
			),
			'grids' => array (
				0 => array (
					'cells' => 1,
				),
				1 => array (
					'cells' => 1,
				),
				2 => array (
					'cells' => 1,
					'style' => array (
						'background_image_attachment' => 2597,
						'background_display' => 'cover',
					),
				),
				3 => array (
					'cells' => 1,
				),
				4 => array (
					'cells' => 1,
				),
				5 => array (
					'cells' => 1,
					'style' => array (
						'class' => 'grey',
					),
				),
				6 => array (
					'cells' => 1,
					'style' => array (
						'background_image_attachment' => 2632,
						'background_display' => 'parallax',
					),
				),
				7 => array (
					'cells' => 1,
					'style' => array (
						'background_display' => 'cover',
					),
				),
				8 => array (
					'cells' => 1,
					'style' => array (
						'class' => 'grey',
					),
				),
			),
			'grid_cells' => array (
				0 => array (
					'grid' => 0,
					'weight' => 1,
				),
				1 => array (
					'grid' => 1,
					'weight' => 1,
				),
				2 => array (
					'grid' => 2,
					'weight' => 1,
				),
				3 => array (
					'grid' => 3,
					'weight' => 1,
				),
				4 => array (
					'grid' => 4,
					'weight' => 1,
				),
				5 => array (
					'grid' => 5,
					'weight' => 1,
				),
				6 => array (
					'grid' => 6,
					'weight' => 1,
				),
				7 => array (
					'grid' => 7,
					'weight' => 1,
				),
				8 => array (
					'grid' => 8,
					'weight' => 1,
				),
			),
		)

	);

	return $layouts;

}
add_filter( 'siteorigin_panels_prebuilt_layouts', 'mymedic_prebuilt_page_layouts' );
