<?php
/**
 * Custom Content block.
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class MyMedic_Custom_Content_Block extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'mymedic_custom_content_block',
			'description' => __( 'Display content in two/three columns.', 'mymedic' )
		);

		// Create the widget.
		parent::__construct(
			'mymedic_custom_content_block',            // $this->id_base
			__( 'Block &raquo; Custom Content', 'mymedic' ), // $this->name
			$widget_options                           // $this->widget_options
		);

		$this->alt_option_name = 'mymedic_custom_content_block';
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$title       = isset( $instance['title'] ) ? $instance['title'] : '';
		$desc        = isset( $instance['desc'] ) ? $instance['desc'] : '';
		$cols        = isset( $instance['cols'] ) ? $instance['cols'] : 'two-one';
		$title_1     = isset( $instance['title_1'] ) ? $instance['title_1'] : '';
		$desc_1      = isset( $instance['desc_1'] ) ? $instance['desc_1'] : '';
		$shortcode_1 = isset( $instance['shortcode_1'] ) ? $instance['shortcode_1'] : '';
		$title_2     = isset( $instance['title_2'] ) ? $instance['title_2'] : '';
		$desc_2      = isset( $instance['desc_2'] ) ? $instance['desc_2'] : '';
		$shortcode_2 = isset( $instance['shortcode_2'] ) ? $instance['shortcode_2'] : '';
		$title_3     = isset( $instance['title_3'] ) ? $instance['title_3'] : '';
		$desc_3      = isset( $instance['desc_3'] ) ? $instance['desc_3'] : '';
		$shortcode_3 = isset( $instance['shortcode_3'] ) ? $instance['shortcode_3'] : '';

		extract( $args );

		switch( $cols ) {
			case 'three':
				$classes_1 = 'col-md-4 col-sm-4 col-xs-12';
				$classes_2 = 'col-md-4 col-sm-4 col-xs-12';
				$classes_3 = 'col-md-4 col-sm-4 col-xs-12';
				break;

			case 'one-two':
				$classes_1 = 'col-md-4 col-sm-4 col-xs-12';
				$classes_2 = 'col-md-8 col-sm-8 col-xs-12';
				break;

			case 'two-one':
			default:
				$classes_1 = 'col-md-8 col-sm-8 col-xs-12';
				$classes_2 = 'col-md-4 col-sm-4 col-xs-12';
				break;
		}

		// Output the theme's $before_widget wrapper.
		echo $before_widget;
		?>
		<div class="container">

			<?php if ( ! empty( $title ) || ! empty( $desc ) ) : ?>
			<div class="general-title text-center">
				<?php if ( ! empty( $title ) ) : ?><h4><?php echo wp_kses_post( $title ); ?></h4><?php endif; ?>
				<?php if ( ! empty( $title ) && ! empty( $desc ) ) : ?><hr><?php endif; ?>
				<?php if ( ! empty( $title ) ) : ?><p class="lead"><?php echo wp_kses_post( $desc ); ?></p><?php endif; ?>
			</div><!-- end general title -->
			<?php endif; ?>

			<div class="row">

			<?php if ( $desc_1 || $shortcode_1 ) : ?>
				<div class="<?php echo esc_attr( $classes_1 ); ?>">
				<?php if ( $title_1 ) : ?>
					<div class="general-title text-left">
						<h4><?php echo wp_kses_post( $title_1 ); ?></h4>
						<hr>
					</div><!-- end general title -->
				<?php endif; ?>
				<?php echo ( $shortcode_1 ) ? do_shortcode( $shortcode_1 ) : $desc_1; ?>
				</div><!-- end Content 1 -->
			<?php endif; ?>

			<?php if ( $desc_2 || $shortcode_2 ) : ?>
				<div class="<?php echo esc_attr( $classes_2 ); ?>">
				<?php if ( $title_2 ) : ?>
					<div class="general-title text-left">
						<h4><?php echo wp_kses_post( $title_2); ?></h4>
						<hr>
					</div><!-- end general title -->
				<?php endif; ?>
				<?php echo ( $shortcode_2 ) ? do_shortcode( $shortcode_2 ) : $desc_2; ?>
				</div><!-- end Content 1 -->
			<?php endif; ?>

			<?php if ( ( 'three' == $cols ) && ( $desc_3 || $shortcode_3) ) : ?>
				<div class="<?php echo esc_attr( $classes_3 ); ?>">
				<?php if ( $title_3 ) : ?>
					<div class="general-title text-left">
						<h4><?php echo wp_kses_post( $title_3 ); ?></h4>
						<hr>
					</div><!-- end general title -->
				<?php endif; ?>
				<?php echo ( $shortcode_3 ) ? do_shortcode( $shortcode_3 ) : $desc_3; ?>
				</div><!-- end Content 1 -->
			<?php endif; ?>

			</div><!-- end row -->
		</div>

		<?php
		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = array();
		$instance['title']       = strip_tags( $new_instance['title'] );
		$instance['desc']        = stripslashes( $new_instance['desc'] );
		$instance['cols']        = stripslashes( $new_instance['cols'] );

		$instance['title_1']     = strip_tags( $new_instance['title_1'] );
		$instance['desc_1']      = stripslashes( $new_instance['desc_1'] );
		$instance['shortcode_1'] = stripslashes( $new_instance['shortcode_1'] );

		$instance['title_2']     = strip_tags( $new_instance['title_2'] );
		$instance['desc_2']      = stripslashes( $new_instance['desc_2'] );
		$instance['shortcode_2'] = stripslashes( $new_instance['shortcode_2'] );

		$instance['title_3']     = strip_tags( $new_instance['title_3'] );
		$instance['desc_3']      = stripslashes( $new_instance['desc_3'] );
		$instance['shortcode_3'] = stripslashes( $new_instance['shortcode_3'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	public function form( $instance ) {

		// Set up default value
		$title       = isset( $instance['title'] ) ? $instance['title'] : '';
		$desc        = isset( $instance['desc'] ) ? $instance['desc'] : '';
		$cols        = isset( $instance['cols'] ) ? $instance['cols'] : 'two-one';
		$title_1     = isset( $instance['title_1'] ) ? $instance['title_1'] : '';
		$desc_1      = isset( $instance['desc_1'] ) ? $instance['desc_1'] : '';
		$shortcode_1 = isset( $instance['shortcode_1'] ) ? $instance['shortcode_1'] : '';
		$title_2     = isset( $instance['title_2'] ) ? $instance['title_2'] : '';
		$desc_2      = isset( $instance['desc_2'] ) ? $instance['desc_2'] : '';
		$shortcode_2 = isset( $instance['shortcode_2'] ) ? $instance['shortcode_2'] : '';
		$title_3     = isset( $instance['title_3'] ) ? $instance['title_3'] : '';
		$desc_3      = isset( $instance['desc_3'] ) ? $instance['desc_3'] : '';
		$shortcode_3 = isset( $instance['shortcode_3'] ) ? $instance['shortcode_3'] : '';
	?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title', 'mymedic' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $title ); ?>" placeholder="<?php esc_attr_e( "Leave blank if you don't want to use Title", 'mymedic' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php esc_html_e( 'Description', 'mymedic' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'desc' ); ?>" name="<?php echo $this->get_field_name( 'desc' ); ?>" value="<?php echo esc_attr( $desc ); ?>" placeholder="<?php esc_attr_e( "Leave blank if you don't want to use Description", 'mymedic' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'cols' ); ?>"><?php esc_html_e( 'Layout', 'mymedic' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'cols' ); ?>" name="<?php echo $this->get_field_name( 'cols' ); ?>" style="width:100%;">
				<option value="two-one" <?php selected( $cols, 'two-one' ); ?>><?php esc_html_e( 'Two Columns / One Column', 'mymedic' ); ?></option>
				<option value="one-two" <?php selected( $cols, 'one-two' ); ?>><?php esc_html_e( 'One Column / Two Columns', 'mymedic' ); ?></option>
				<option value="three" <?php selected( $cols, 'three' ); ?>><?php esc_html_e( 'Three Columns', 'mymedic' ); ?></option>
			</select>
		</p>

		<p>
			<h3><?php _e( 'Content 1', 'mymedic' ); ?></h3>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'title_1' ); ?>">
				<?php _e( 'Title', 'mymedic' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title_1' ); ?>" name="<?php echo $this->get_field_name( 'title_1' ); ?>" value="<?php echo esc_attr( $title_1 ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc_1' ); ?>">
				<?php _e( 'Description', 'mymedic' ); ?>
			</label>
			<textarea class="widefat" name="<?php echo $this->get_field_name( 'desc_1' ); ?>" id="<?php echo $this->get_field_id( 'desc_1' ); ?>" cols="30" rows="6"><?php echo stripslashes( $desc_1 ); ?></textarea>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'shortcode_1' ); ?>">
				<?php _e( 'Shortcode', 'mymedic' ); ?> <small><?php _e( 'Use Shortcode for the content instead.', 'mymedic' ); ?></small>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'shortcode_1' ); ?>" name="<?php echo $this->get_field_name( 'shortcode_1' ); ?>" value="<?php echo esc_attr( $shortcode_1 ); ?>" placeholder="[contact-shortcode]" />
		</p>

		<p>
			<h3><?php _e( 'Content 2', 'mymedic' ); ?></h3>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'title_2' ); ?>">
				<?php _e( 'Title', 'mymedic' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title_2' ); ?>" name="<?php echo $this->get_field_name( 'title_2' ); ?>" value="<?php echo esc_attr( $title_2 ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc_2' ); ?>">
				<?php _e( 'Description', 'mymedic' ); ?>
			</label>
			<textarea class="widefat" name="<?php echo $this->get_field_name( 'desc_2' ); ?>" id="<?php echo $this->get_field_id( 'desc_2' ); ?>" cols="30" rows="6"><?php echo stripslashes( $desc_2 ); ?></textarea>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'shortcode_2' ); ?>">
				<?php _e( 'Shortcode', 'mymedic' ); ?> <small><?php _e( 'Use Shortcode for the content instead.', 'mymedic' ); ?></small>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'shortcode_2' ); ?>" name="<?php echo $this->get_field_name( 'shortcode_2' ); ?>" value="<?php echo esc_attr( $shortcode_2 ); ?>" placeholder="[contact-shortcode]" />
		</p>

		<p>
			<h3><?php _e( 'Content 3', 'mymedic' ); ?></h3>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'title_3' ); ?>">
				<?php _e( 'Title', 'mymedic' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title_3' ); ?>" name="<?php echo $this->get_field_name( 'title_3' ); ?>" value="<?php echo esc_attr( $title_3 ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc_3' ); ?>">
				<?php _e( 'Description', 'mymedic' ); ?>
			</label>
			<textarea class="widefat" name="<?php echo $this->get_field_name( 'desc_3' ); ?>" id="<?php echo $this->get_field_id( 'desc_3' ); ?>" cols="30" rows="6"><?php echo stripslashes( $desc_3 ); ?></textarea>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'shortcode_3' ); ?>">
				<?php _e( 'Shortcode', 'mymedic' ); ?> <small><?php _e( 'Use Shortcode for the content instead.', 'mymedic' ); ?></small>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'shortcode_3' ); ?>" name="<?php echo $this->get_field_name( 'shortcode_3' ); ?>" value="<?php echo esc_attr( $shortcode_3 ); ?>" placeholder="[contact-shortcode]" />
		</p>
	<?php
	}

}
