<?php
/**
 * Doctor Carousel block.
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class MyMedic_Doctor_Carousel_Block extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'     => 'mymedic_doctor_carousel_block section',
			'description'   => __( 'Display list of doctors in carousel.', 'mymedic' )
		);

		// Create the widget.
		parent::__construct(
			'mymedic_doctor_carousel_block',            // $this->id_base
			__( 'Block &raquo; Doctor Carousel', 'mymedic' ), // $this->name
			$widget_options                           // $this->widget_options
		);

		$this->alt_option_name = 'mymedic_doctor_carousel_block';
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$title   = isset( $instance['title'] ) ? $instance['title'] : '';
		$desc    = isset( $instance['desc'] ) ? $instance['desc'] : '';
		// if $num = 0, change to -1; means show all
		$num     = isset( $instance['num'] ) && ( 0 != $instance['num'] ) ? intval( $instance['num'] ) : -1;
		$cat     = isset( $instance['cat'] ) ? intval( $instance['cat'] ) : '';
		$order   = isset( $instance['order'] ) ? $instance['order'] : '';
		$orderby = isset( $instance['orderby'] ) ? $instance['orderby'] : '';
		$overlay = isset( $instance['overlay'] ) ? $instance['overlay'] : '';

		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

			// Posts query arguments.
			$args = array(
				'posts_per_page' => $num,
				'post_type'      => 'doctor',
				'order'          => $order,
				'orderby'        => $orderby
			);

			if ( $cat ) {
				$args['tax_query'] = array(
					array(
						'taxonomy' => 'speciality',
						'terms'    => $cat,
					)
				);
			}

			// Allow dev to filter the post arguments.
			$query = apply_filters( 'mymedic_doctor_carousel_block', $args );

			// The post query.
			$posts = new WP_Query( $query );

			if ( $posts->have_posts() ) : ?>
				<?php if ( $overlay ) : ?><div class="lightoverlay"></div><?php endif; ?>
				<div class="container">

					<?php if ( ! empty( $title ) || ! empty( $desc ) ) : ?>
					<div class="general-title text-center">
						<?php if ( ! empty( $title ) ) : ?><h4><?php echo wp_kses_post( $title ); ?></h4><?php endif; ?>
						<?php if ( ! empty( $title ) && ! empty( $desc ) ) : ?><hr><?php endif; ?>
						<?php if ( ! empty( $title ) ) : ?><p class="lead"><?php echo wp_kses_post( $desc ); ?></p><?php endif; ?>
					</div><!-- end general title -->
					<?php endif; ?>

					<div class="owl-team owl-custom text-center">
					<?php while ( $posts->have_posts() ) : $posts->the_post(); ?>

						<div class="owl-featured team-member">
							<div class="entry">
								<?php the_post_thumbnail( 'mymedic-doctor', array( 'class' => 'img-responsive', 'alt' => esc_attr( get_the_title() ) ) ); ?>
								<div class="magnifier">
									<div class="buttons">
										<?php if ( get_post_meta( get_the_ID(), 'junkie_types_doctor_twitter_url', true ) ) : ?>
											<a class="st" href="<?php echo esc_url( get_post_meta( get_the_ID(), 'junkie_types_doctor_twitter_url', true ) ) ?>"><i class="fa fa-twitter"></i></a>
										<?php endif; ?>
										<?php if ( get_post_meta( get_the_ID(), 'junkie_types_doctor_facebook_url', true ) ) : ?>
											<a class="st" href="<?php echo esc_url( get_post_meta( get_the_ID(), 'junkie_types_doctor_facebook_url', true ) ) ?>"><i class="fa fa-facebook"></i></a>
										<?php endif; ?>
										<?php if ( get_post_meta( get_the_ID(), 'junkie_types_doctor_googleplus_url', true ) ) : ?>
											<a class="st" href="<?php echo esc_url( get_post_meta( get_the_ID(), 'junkie_types_doctor_googleplus_url', true ) ) ?>"><i class="fa fa-google-plus"></i></a>
										<?php endif; ?>
										<?php if ( get_post_meta( get_the_ID(), 'junkie_types_doctor_linkedin_url', true ) ) : ?>
											<a class="st" href="<?php echo esc_url( get_post_meta( get_the_ID(), 'junkie_types_doctor_linkedin_url', true ) ) ?>"><i class="fa fa-linkedin"></i></a>
										<?php endif; ?>
									</div>
								</div><!-- end magnifier -->
							</div><!-- end entry -->
							<div class="team-desc">
								<h4>
									<a href="<?php the_permalink(); ?>">
										<?php the_title(); ?>
										<?php $speciality = get_the_terms( get_the_ID(), 'speciality' );
											if ( $speciality ) { ?>
											<span>|</span>
											<small><?php echo esc_html( $speciality[0]->name ); ?></small>
										<?php } ?>
									</a>
								</h4>
								<?php the_excerpt(); ?>
								<a href="<?php the_permalink(); ?>" class="btn btn-primary btn-sm"><?php esc_html_e( 'Read more', 'mymedic' ); ?></a>
							</div>
						</div><!-- end team_member -->

					<?php endwhile; ?>
					</div><!-- row -->

				</div><!-- end container -->

			<?php endif;

			// Restore original Post Data.
			wp_reset_postdata();

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = array();
		$instance['title']   = strip_tags( $new_instance['title'] );
		$instance['desc']    = stripslashes( $new_instance['desc'] );
		$instance['num']     = intval( $new_instance['num'] );
		$instance['cat']     = intval( $new_instance['cat'] );
		$instance['order']   = stripslashes( $new_instance['order'] );
		$instance['orderby'] = stripslashes( $new_instance['orderby'] );
		$instance['overlay'] = intval( $new_instance['overlay'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	public function form( $instance ) {

		// Set up default value
		$title   = isset( $instance['title'] ) ? $instance['title'] : esc_html__( 'Our Experienced Doctors', 'mymedic' );
		$desc    = isset( $instance['desc'] ) ? $instance['desc'] : esc_html__( 'Listed below our professional and experienced hospital personals', 'mymedic' );
		$num     = isset( $instance['num'] ) ? intval( $instance['num'] ) : 5;
		$cat     = isset( $instance['cat'] ) ? intval( $instance['cat'] ) : '';
		$order   = isset( $instance['order'] ) ? $instance['order'] : 'asc';
		$orderby = isset( $instance['orderby'] ) ? $instance['orderby'] : 'name';
		$overlay = isset( $instance['overlay'] ) ? $instance['overlay'] : '';
	?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title', 'mymedic' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $title ); ?>" placeholder="<?php esc_attr_e( "Leave blank if you don't want to use Title", 'mymedic' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php esc_html_e( 'Description', 'mymedic' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'desc' ); ?>" name="<?php echo $this->get_field_name( 'desc' ); ?>" value="<?php echo esc_attr( $desc ); ?>" placeholder="<?php esc_attr_e( "Leave blank if you don't want to use Description", 'mymedic' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'num' ); ?>"><?php esc_html_e( 'Number of doctors to show:', 'mymedic' ); ?></label>
			<input class="tiny-text" id="<?php echo $this->get_field_id( 'num' ); ?>" name="<?php echo $this->get_field_name( 'num' ); ?>" type="number" step="1" min="0" value="<?php echo esc_attr( $num ); ?>" size="3" />
			<small><?php esc_html_e( 'Use 0 to show all.', 'mymedic' ); ?></small>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'cat' ); ?>"><?php esc_html_e( 'Choose Specialty:', 'mymedic' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'cat' ); ?>" name="<?php echo $this->get_field_name( 'cat' ); ?>" style="width:100%;">
				<?php $categories = get_terms( 'speciality' ); ?>
				<option value="0" <?php selected( $cat, 0 ); ?>><?php echo esc_html__( 'All', 'mymedic' ); ?></option>
				<?php foreach( $categories as $category ) { ?>
					<option value="<?php echo absint( $category->term_id ); ?>" <?php selected( $cat, absint( $category->term_id ) ); ?>><?php echo esc_html( $category->name ); ?></option>
				<?php } ?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php esc_html_e( 'Order By:', 'mymedic' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'orderby' ); ?>" name="<?php echo $this->get_field_name( 'orderby' ); ?>" style="width:100%;">
				<option value="name" <?php selected( $orderby, 'name' ); ?>><?php esc_html_e( 'Name', 'mymedic' ); ?></option>
				<option value="menu_order" <?php selected( $orderby, 'menu_order' ); ?>><?php esc_html_e( 'Order', 'mymedic' ); ?></option>
				<option value="date" <?php selected( $orderby, 'date' ); ?>><?php esc_html_e( 'Date', 'mymedic' ); ?></option>
				<option value="rand" <?php selected( $orderby, 'rand' ); ?>><?php esc_html_e( 'Random', 'mymedic' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'order' ); ?>"><?php esc_html_e( 'Order:', 'mymedic' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'order' ); ?>" name="<?php echo $this->get_field_name( 'order' ); ?>" style="width:100%;">
				<option value="asc" <?php selected( $order, 'asc' ); ?>><?php esc_html_e( 'Ascending', 'mymedic' ); ?></option>
				<option value="desc" <?php selected( $order, 'desc' ); ?>><?php esc_html_e( 'Descending', 'mymedic' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'overlay' ); ?>"><?php esc_html_e( 'Use Overlay', 'mymedic' ); ?></label>
			<input type="checkbox" id="<?php echo $this->get_field_id( 'overlay' ); ?>" name="<?php echo $this->get_field_name( 'overlay' ); ?>" value="1" <?php checked( $overlay, 1 ); ?> />
			<sub><?php esc_html_e( "Add light overlay in the background. Useful when you're using a Background Image", 'mymedic' ); ?></sub>
		</p>
	<?php
	}

}
