<?php
/**
 * Number block.
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class MyMedic_Number_Block extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'     => 'mymedic_number_block section',
			'description'   => __( 'Display statistics in numbers.', 'mymedic' )
		);

		// Create the widget.
		parent::__construct(
			'mymedic_number_block',            // $this->id_base
			__( 'Block &raquo; Number', 'mymedic' ), // $this->name
			$widget_options                           // $this->widget_options
		);

		$this->alt_option_name = 'mymedic_number_block';
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$title    = isset( $instance['title'] ) ? $instance['title'] : '';
		$desc     = isset( $instance['desc'] ) ? $instance['desc'] : '';
		$overlay  = isset( $instance['overlay'] ) ? $instance['overlay'] : '';
		$icon_1   = isset( $instance['icon_1'] ) ? $instance['icon_1'] : '';
		$title_1  = isset( $instance['title_1'] ) ? $instance['title_1'] : '';
		$number_1 = isset( $instance['number_1'] ) ? $instance['number_1'] : '';
		$icon_2   = isset( $instance['icon_2'] ) ? $instance['icon_2'] : '';
		$title_2  = isset( $instance['title_2'] ) ? $instance['title_2'] : '';
		$number_2 = isset( $instance['number_2'] ) ? $instance['number_2'] : '';
		$icon_3   = isset( $instance['icon_3'] ) ? $instance['icon_3'] : '';
		$title_3  = isset( $instance['title_3'] ) ? $instance['title_3'] : '';
		$number_3 = isset( $instance['number_3'] ) ? $instance['number_3'] : '';
		$icon_4   = isset( $instance['icon_4'] ) ? $instance['icon_4'] : '';
		$title_4  = isset( $instance['title_4'] ) ? $instance['title_4'] : '';
		$number_4 = isset( $instance['number_4'] ) ? $instance['number_4'] : '';

		extract( $args );

		// set column width based on how many Number exist
		if ( $icon_4 ) {
			$classes = 'col-md-3 col-sm-6 col-xs-12';
		} elseif ( $icon_3 ) {
			$classes = 'col-md-4 col-sm-4 col-xs-12';
		} elseif( $icon_2 ) {
			$classes = 'col-md-6 col-sm-6 col-xs-12';
		} elseif( $icon_1 ) {
			$classes = 'col-md-12 col-sm-12 col-xs-12';
		} else {
			// bail if no Number set
			return;
		}

		// Output the theme's $before_widget wrapper.
		echo $before_widget;
		?>
		<?php if ( $overlay ) : ?><div class="lightoverlay"></div><?php endif; ?>
		<div class="container">

			<?php if ( ! empty( $title ) || ! empty( $desc ) ) : ?>
			<div class="general-title text-center">
				<?php if ( ! empty( $title ) ) : ?><h4><?php echo wp_kses_post( $title ); ?></h4><?php endif; ?>
				<?php if ( ! empty( $title ) && ! empty( $desc ) ) : ?><hr><?php endif; ?>
				<?php if ( ! empty( $title ) ) : ?><p class="lead"><?php echo wp_kses_post( $desc ); ?></p><?php endif; ?>
			</div><!-- end general title -->
			<?php endif; ?>

			<div class="row">
				<?php if ( $icon_1 ) : ?>
				<div class="<?php echo esc_attr( $classes ); ?>">
					<div class="fun-facts text-center">
						<span class="fun-icon"><i class="fa <?php echo esc_attr( $icon_1 ); ?>"></i></span>
						<h3><?php echo esc_html__( $title_1 ); ?></h3>
						<p class="stat-count"><?php echo esc_html__( $number_1 ); ?></p>
					</div><!-- end service-box -->
				</div><!-- end col -->
				<?php endif; ?>
				<?php if ( $icon_2 ) : ?>
				<div class="<?php echo esc_attr( $classes ); ?>">
					<div class="fun-facts text-center">
						<span class="fun-icon"><i class="fa <?php echo esc_attr( $icon_2 ); ?>"></i></span>
						<h3><?php echo esc_html__( $title_2 ); ?></h3>
						<p class="stat-count"><?php echo esc_html__( $number_2 ); ?></p>
					</div><!-- end service-box -->
				</div><!-- end col -->
				<?php endif; ?>
				<?php if ( $icon_3 ) : ?>
				<div class="<?php echo esc_attr( $classes ); ?>">
					<div class="fun-facts text-center">
						<span class="fun-icon"><i class="fa <?php echo esc_attr( $icon_3 ); ?>"></i></span>
						<h3><?php echo esc_html__( $title_3 ); ?></h3>
						<p class="stat-count"><?php echo esc_html__( $number_3 ); ?></p>
					</div><!-- end service-box -->
				</div><!-- end col -->
				<?php endif; ?>
				<?php if ( $icon_4 ) : ?>
				<div class="<?php echo esc_attr( $classes ); ?>">
					<div class="fun-facts text-center">
						<span class="fun-icon"><i class="fa <?php echo esc_attr( $icon_4 ); ?>"></i></span>
						<h3><?php echo esc_html__( $title_4 ); ?></h3>
						<p class="stat-count"><?php echo esc_html__( $number_4 ); ?></p>
					</div><!-- end service-box -->
				</div><!-- end col -->
				<?php endif; ?>
			</div><!-- end row -->

		</div><!-- end container -->
		<?php
		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = array();
		$instance['title']    = strip_tags( $new_instance['title'] );
		$instance['desc']     = stripslashes( $new_instance['desc'] );
		$instance['overlay']  = intval( $new_instance['overlay'] );
		$instance['icon_1']   = stripslashes( $new_instance['icon_1'] );
		$instance['title_1']  = stripslashes( $new_instance['title_1'] );
		$instance['number_1'] = intval( $new_instance['number_1'] );
		$instance['icon_2']   = stripslashes( $new_instance['icon_2'] );
		$instance['title_2']  = stripslashes( $new_instance['title_2'] );
		$instance['number_2'] = intval( $new_instance['number_2'] );
		$instance['icon_3']   = stripslashes( $new_instance['icon_3'] );
		$instance['title_3']  = stripslashes( $new_instance['title_3'] );
		$instance['number_3'] = intval( $new_instance['number_3'] );
		$instance['icon_4']   = stripslashes( $new_instance['icon_4'] );
		$instance['title_4']  = stripslashes( $new_instance['title_4'] );
		$instance['number_4'] = intval( $new_instance['number_4'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	public function form( $instance ) {

		// Set up default value
		$title    = isset( $instance['title'] ) ? $instance['title'] : esc_html__( 'MyMedic In Numbers', 'mymedic' );
		$desc     = isset( $instance['desc'] ) ? $instance['desc'] : esc_html__( 'Listed below our excellent numbers in medical field!', 'mymedic' );
		$overlay  = isset( $instance['overlay'] ) ? $instance['overlay'] : '';
		$icon_1   = isset( $instance['icon_1'] ) ? $instance['icon_1'] : '';
		$title_1  = isset( $instance['title_1'] ) ? $instance['title_1'] : '';
		$number_1 = isset( $instance['number_1'] ) ? $instance['number_1'] : '';
		$icon_2   = isset( $instance['icon_2'] ) ? $instance['icon_2'] : '';
		$title_2  = isset( $instance['title_2'] ) ? $instance['title_2'] : '';
		$number_2 = isset( $instance['number_2'] ) ? $instance['number_2'] : '';
		$icon_3   = isset( $instance['icon_3'] ) ? $instance['icon_3'] : '';
		$title_3  = isset( $instance['title_3'] ) ? $instance['title_3'] : '';
		$number_3 = isset( $instance['number_3'] ) ? $instance['number_3'] : '';
		$icon_4   = isset( $instance['icon_4'] ) ? $instance['icon_4'] : '';
		$title_4  = isset( $instance['title_4'] ) ? $instance['title_4'] : '';
		$number_4 = isset( $instance['number_4'] ) ? $instance['number_4'] : '';
	?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title', 'mymedic' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $title ); ?>" placeholder="<?php esc_attr_e( "Leave blank if you don't want to use Title", 'mymedic' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php esc_html_e( 'Description', 'mymedic' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'desc' ); ?>" name="<?php echo $this->get_field_name( 'desc' ); ?>" value="<?php echo esc_attr( $desc ); ?>" placeholder="<?php esc_attr_e( "Leave blank if you don't want to use Description", 'mymedic' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'overlay' ); ?>"><?php esc_html_e( 'Use Overlay', 'mymedic' ); ?></label>
			<input type="checkbox" id="<?php echo $this->get_field_id( 'overlay' ); ?>" name="<?php echo $this->get_field_name( 'overlay' ); ?>" value="1" <?php checked( $overlay, 1 ); ?> />
			<sub><?php esc_html_e( "Add light overlay in the background. Useful when you're using a Background Image", 'mymedic' ); ?></sub>
		</p>

		<hr>

		<?php
		$fields = array(
			'1' => array( 'icon_1', $icon_1, 'title_1', $title_1, 'number_1', $number_1, 'fa-heartbeat' ),
			'2' => array( 'icon_2', $icon_2, 'title_2', $title_2, 'number_2', $number_2, 'fa-hospital-o' ),
			'3' => array( 'icon_3', $icon_3, 'title_3', $title_3, 'number_3', $number_3, 'fa-h-square' ),
			'4' => array( 'icon_4', $icon_4, 'title_4', $title_4, 'number_4', $number_4, 'fa-hourglass-half' )
		);

		foreach ( $fields as $key => $field ) :
		?>
		<h3><?php printf( esc_html__( 'Number %s', 'mymedic' ), $key ); ?></h3>
		<p>
			<label style="display: inline-block; width: 80px" for="<?php echo $this->get_field_id( $field[0] ); ?>"><?php esc_html_e( 'Icon Class', 'mymedic' ); ?></label>
			<input type="text" class="regular-text" id="<?php echo $this->get_field_id( $field[0] ); ?>" name="<?php echo $this->get_field_name( $field[0] ); ?>" value="<?php echo esc_attr( $field[1] ); ?>" placeholder="<?php echo esc_attr( $field[6] ); ?>" />
			<small><?php echo wp_kses_post( __( 'For reference, check this <a href="http://fontawesome.io/icons/" target="_blank">list</a>', 'mymedic' ) ); ?></small>
		</p>
		<p>
			<label style="display: inline-block; width: 80px" for="<?php echo $this->get_field_id( $field[2] ); ?>"><?php esc_html_e( 'Title', 'mymedic' ); ?></label>
			<input type="text" class="regular-text" id="<?php echo $this->get_field_id( $field[2] ); ?>" name="<?php echo $this->get_field_name( $field[2] ); ?>" value="<?php echo esc_attr( $field[3] ); ?>" />
		</p>
		<p>
			<label style="display: inline-block; width: 80px" for="<?php echo $this->get_field_id( $field[4] ); ?>"><?php esc_html_e( 'Number', 'mymedic' ); ?></label>
			<input type="number" class="small-text" id="<?php echo $this->get_field_id( $field[4] ); ?>" name="<?php echo $this->get_field_name( $field[4] ); ?>" value="<?php echo esc_attr( $field[5] ); ?>" />
		</p>
		<?php endforeach; ?>

	<?php
	}

}
