<?php
/**
 * Portfolio block.
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class MyMedic_Portfolio_Block extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'     => 'mymedic_portfolio_block section',
			'description'   => __( 'Display list of portfolio.', 'mymedic' )
		);

		// Create the widget.
		parent::__construct(
			'mymedic_portfolio_block',            // $this->id_base
			__( 'Block &raquo; Portfolio', 'mymedic' ), // $this->name
			$widget_options                           // $this->widget_options
		);

		$this->alt_option_name = 'mymedic_portfolio_block';

		// enqueue scripts
		add_action( 'wp_enqueue_scripts', array( $this, 'load_scripts' ) );
	}

	/**
	 * Enqueue required CSS and JS
	 */
	public function load_scripts() {
		// check if Block is used
		if ( is_active_widget( false, false, $this->id_base ) ) {
			wp_enqueue_style( 'mymedic-prettyphoto', trailingslashit( get_template_directory_uri() ) . 'assets/css/prettyPhoto.min.css' );

			// merge from: isotope.js, imagesloaded.pkgd.js, jquery.prettyPhoto.js, masonry-one.js
			wp_enqueue_script( 'mymedic-portfolio', trailingslashit( get_template_directory_uri() ) . 'assets/js/portfolio.min.js', array( 'jquery' ), null, true );
		}
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$title   = isset( $instance['title'] ) ? $instance['title'] : '';
		$desc    = isset( $instance['desc'] ) ? $instance['desc'] : '';
		// if $num = 0, change to -1; means show all
		$num     = isset( $instance['num'] ) && ( 0 != $instance['num'] ) ? intval( $instance['num'] ) : -1;
		$order   = isset( $instance['order'] ) ? $instance['order'] : '';
		$orderby = isset( $instance['orderby'] ) ? $instance['orderby'] : '';
		$url     = isset( $instance['url'] ) ? $instance['url'] : '';
		$button  = isset( $instance['button'] ) ? $instance['button'] : '';
		$overlay = isset( $instance['overlay'] ) ? $instance['overlay'] : '';

		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

			// Posts query arguments.
			$args = array(
				'posts_per_page' => $num,
				'post_type'      => 'jetpack-portfolio',
				'order'          => $order,
				'orderby'        => $orderby
			);

			// Allow dev to filter the post arguments.
			$query = apply_filters( 'mymedic_portfolio_block', $args );

			// The post query.
			$posts = new WP_Query( $query );

			if ( $posts->have_posts() ) : ?>
				<?php if ( $overlay ) : ?><div class="lightoverlay"></div><?php endif; ?>
				<div class="container">

					<?php if ( ! empty( $title ) || ! empty( $desc ) ) : ?>
					<div class="general-title text-center">
						<?php if ( ! empty( $title ) ) : ?><h4><?php echo wp_kses_post( $title ); ?></h4><?php endif; ?>
						<?php if ( ! empty( $title ) && ! empty( $desc ) ) : ?><hr><?php endif; ?>
						<?php if ( ! empty( $title ) ) : ?><p class="lead"><?php echo wp_kses_post( $desc ); ?></p><?php endif; ?>
					</div><!-- end general title -->
					<?php endif; ?>

					<?php $types = get_terms( 'jetpack-portfolio-type', array( 'hide_empty' => false ) ); ?>
					<?php if ( $types && ! is_wp_error( $types ) ) : ?>
						<div class="text-center clearfix">
							<nav class="portfolio-filter">
								<ul>
									<li><a href="#" data-filter="*"><i class="fa fa-filter"></i> <?php esc_html_e( 'All', 'mymedic' ); ?></a></li>
									<?php foreach( $types as $type ) : ?>
										<li><a href="#" data-filter="<?php echo esc_attr( '.' . $type->slug ); ?>"><?php echo esc_html( $type->name ); ?></a></li>
									<?php endforeach; ?>
								</ul>
							</nav>
						</div><!-- end text-center -->
					<?php endif; ?>

					<div class="portfolio">
					<?php while ( $posts->have_posts() ) : $posts->the_post(); ?>

						<?php
						$terms = get_the_terms( get_the_ID(), 'jetpack-portfolio-type' );
						$term_classes = implode( ' ', array_map( function ( $entry ) {
							return $entry->slug;
						}, $terms) );
						?>
						<div class="pitem entry item-w1 item-h1 <?php echo esc_attr( $term_classes ); ?>">
							<?php the_post_thumbnail( 'medium', array( 'class' => 'img-responsive', 'alt' => esc_attr( get_the_title() ) ) ); ?>
							<div class="magnifier">
								<div class="buttons">
									<a data-rel="prettyPhoto" href="<?php the_post_thumbnail_url( 'full' ); ?>" class="st" rel="bookmark"><span class="fa fa-search"></span></a>
									<a class="st" rel="bookmark" href="<?php the_permalink(); ?>"><span class="fa fa-link"></span></a>
								</div>
							</div><!-- end magnifier -->
						</div>

					<?php endwhile; ?>
					</div><!-- .portfolio -->

					<?php if ( ! empty( $url ) && ! empty( $button ) ) : ?>
						<hr class="invis">

						<div class="row text-center">
							<div class="col-md-12">
								<a class="btn btn-default btn-lg" href="<?php echo esc_url( $url ); ?>"><?php echo esc_html( $button ); ?></a>
							</div><!-- end col -->
						</div><!-- end row -->
					<?php endif; ?>

				</div><!-- end container -->

			<?php endif;

			// Restore original Post Data.
			wp_reset_postdata();

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = array();
		$instance['title']   = strip_tags( $new_instance['title'] );
		$instance['desc']    = stripslashes( $new_instance['desc'] );
		$instance['num']     = intval( $new_instance['num'] );
		$instance['order']   = stripslashes( $new_instance['order'] );
		$instance['orderby'] = stripslashes( $new_instance['orderby'] );
		$instance['url']     = esc_url_raw( $new_instance['url'] );
		$instance['button']  = stripslashes( $new_instance['button'] );
		$instance['overlay'] = intval( $new_instance['overlay'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	public function form( $instance ) {

		// Set up default value
		$title   = isset( $instance['title'] ) ? $instance['title'] : esc_html__( 'From Gallery', 'mymedic' );
		$desc    = isset( $instance['desc'] ) ? $instance['desc'] : esc_html__( 'Listed all our awesome gallery photos!', 'mymedic' );
		$num     = isset( $instance['num'] ) ? intval( $instance['num'] ) : 0;
		$order   = isset( $instance['order'] ) ? $instance['order'] : 'asc';
		$orderby = isset( $instance['orderby'] ) ? $instance['orderby'] : 'name';
		$url     = isset( $instance['url'] ) ? $instance['url'] : '';
		$button  = isset( $instance['button'] ) ? $instance['button'] : esc_html__( 'View All', 'mymedic' );
		$overlay = isset( $instance['overlay'] ) ? $instance['overlay'] : '';
	?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title', 'mymedic' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $title ); ?>" placeholder="<?php esc_attr_e( "Leave blank if you don't want to use Title", 'mymedic' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php esc_html_e( 'Description', 'mymedic' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'desc' ); ?>" name="<?php echo $this->get_field_name( 'desc' ); ?>" value="<?php echo esc_attr( $desc ); ?>" placeholder="<?php esc_attr_e( "Leave blank if you don't want to use Description", 'mymedic' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'num' ); ?>"><?php esc_html_e( 'Number of portfolios to show:', 'mymedic' ); ?></label>
			<input class="tiny-text" id="<?php echo $this->get_field_id( 'num' ); ?>" name="<?php echo $this->get_field_name( 'num' ); ?>" type="number" step="1" min="0" value="<?php echo esc_attr( $num ); ?>" size="3" />
			<small><?php esc_html_e( 'Use 0 to show all.', 'mymedic' ); ?></small>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php esc_html_e( 'Order By:', 'mymedic' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'orderby' ); ?>" name="<?php echo $this->get_field_name( 'orderby' ); ?>" style="width:100%;">
				<option value="name" <?php selected( $orderby, 'name' ); ?>><?php esc_html_e( 'Name', 'mymedic' ); ?></option>
				<option value="menu_order" <?php selected( $orderby, 'menu_order' ); ?>><?php esc_html_e( 'Order', 'mymedic' ); ?></option>
				<option value="date" <?php selected( $orderby, 'date' ); ?>><?php esc_html_e( 'Date', 'mymedic' ); ?></option>
				<option value="rand" <?php selected( $orderby, 'rand' ); ?>><?php esc_html_e( 'Random', 'mymedic' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'order' ); ?>"><?php esc_html_e( 'Order:', 'mymedic' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'order' ); ?>" name="<?php echo $this->get_field_name( 'order' ); ?>" style="width:100%;">
				<option value="asc" <?php selected( $order, 'asc' ); ?>><?php esc_html_e( 'Ascending', 'mymedic' ); ?></option>
				<option value="desc" <?php selected( $order, 'desc' ); ?>><?php esc_html_e( 'Descending', 'mymedic' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'url' ); ?>"><?php esc_html_e( 'Button URL', 'mymedic' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'url' ); ?>" name="<?php echo $this->get_field_name( 'url' ); ?>" value="<?php echo esc_attr( $url ); ?>" placeholder="http://" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'button' ); ?>"><?php esc_html_e( 'Button Text', 'mymedic' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'button' ); ?>" name="<?php echo $this->get_field_name( 'button' ); ?>" value="<?php echo esc_attr( $button ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'overlay' ); ?>"><?php esc_html_e( 'Use Overlay', 'mymedic' ); ?></label>
			<input type="checkbox" id="<?php echo $this->get_field_id( 'overlay' ); ?>" name="<?php echo $this->get_field_name( 'overlay' ); ?>" value="1" <?php checked( $overlay, 1 ); ?> />
			<sub><?php esc_html_e( "Add light overlay in the background. Useful when you're using a Background Image", 'mymedic' ); ?></sub>
		</p>
	<?php
	}

}
