<?php
/**
 * Tabs block.
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class MyMedic_Tabs_Block extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'     => 'mymedic_tabs_block section',
			'description'   => __( 'Display list of all departments/services in tabs.', 'mymedic' )
		);

		// Create the widget.
		parent::__construct(
			'mymedic_tabs_block',            // $this->id_base
			__( 'Block &raquo; Tabs', 'mymedic' ), // $this->name
			$widget_options                           // $this->widget_options
		);

		$this->alt_option_name = 'mymedic_tabs_block';
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$title   = isset( $instance['title'] ) ? $instance['title'] : '';
		$desc    = isset( $instance['desc'] ) ? $instance['desc'] : '';
		$type    = isset( $instance['type'] ) ? $instance['type'] : 'department';
		$order   = isset( $instance['order'] ) ? $instance['order'] : '';
		$orderby = isset( $instance['orderby'] ) ? $instance['orderby'] : '';

		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

			// Posts query arguments.
			$args = array(
				'posts_per_page' => -1,
				'post_type'      => $type,
				'order'          => $order,
				'orderby'        => $orderby
			);

			// Allow dev to filter the post arguments.
			$query = apply_filters( 'mymedic_tabs_block', $args );

			// The post query.
			$posts = new WP_Query( $query );

			if ( $posts->have_posts() ) : ?>

				<div class="container">

					<?php if ( ! empty( $title ) || ! empty( $desc ) ) : ?>
					<div class="general-title text-center">
						<?php if ( ! empty( $title ) ) : ?><h4><?php echo wp_kses_post( $title ); ?></h4><?php endif; ?>
						<?php if ( ! empty( $title ) && ! empty( $desc ) ) : ?><hr><?php endif; ?>
						<?php if ( ! empty( $title ) ) : ?><p class="lead"><?php echo wp_kses_post( $desc ); ?></p><?php endif; ?>
					</div><!-- end general title -->
					<?php endif; ?>

					<div class="custom_tab_2 row">

						<div class="col-md-3">
							<ul class="nav nav-pills nav-stacked another_tab">
							<?php while ( $posts->have_posts() ) : $posts->the_post(); ?>

								<li<?php echo ( 0 == $posts->current_post ) ? ' class="' . esc_attr( 'active' ) . '"' : ''; ?>>
									<a href="<?php echo esc_url( '#tabbed_' . get_the_ID() ); ?>"><?php the_title(); ?></a>
								</li>

							<?php endwhile; ?>
							</ul>
						</div>

						<div class="col-md-9">
							<div class="tab-content">
							<?php while ( $posts->have_posts() ) : $posts->the_post(); ?>

								<div class="tab-pane<?php echo ( 0 == $posts->current_post ) ? esc_attr( ' active' ) : ''; ?>" id="<?php echo esc_attr( 'tabbed_' . get_the_ID() ); ?>">
									<?php $class = ( 0 == $posts->current_post % 2 ) ? 'img-responsive alignleft' : 'img-responsive alignright'; ?>
									<?php the_post_thumbnail( 'mymedic-square-thumbnail', array( 'class' => $class, 'alt' => esc_attr( get_the_title() ) ) ); ?>
									<?php the_content(); ?>
								</div>

							<?php endwhile; ?>
							</div><!-- .tab-content -->
						</div>

					</div><!-- .custom_tab_2 -->

				</div><!-- end container -->

			<?php endif;

			// Restore original Post Data.
			wp_reset_postdata();

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = array();
		$instance['title']   = strip_tags( $new_instance['title'] );
		$instance['desc']    = stripslashes( $new_instance['desc'] );
		$instance['type']    = stripslashes( $new_instance['type'] );
		$instance['order']   = stripslashes( $new_instance['order'] );
		$instance['orderby'] = stripslashes( $new_instance['orderby'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	public function form( $instance ) {

		// Set up default value
		$title   = isset( $instance['title'] ) ? $instance['title'] : '';
		$desc    = isset( $instance['desc'] ) ? $instance['desc'] : '';
		$type    = isset( $instance['type'] ) ? $instance['type'] : 'department';
		$order   = isset( $instance['order'] ) ? $instance['order'] : '';
		$orderby = isset( $instance['orderby'] ) ? $instance['orderby'] : '';
	?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title', 'mymedic' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $title ); ?>" placeholder="<?php esc_attr_e( "Leave blank if you don't want to use Title", 'mymedic' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php esc_html_e( 'Description', 'mymedic' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'desc' ); ?>" name="<?php echo $this->get_field_name( 'desc' ); ?>" value="<?php echo esc_attr( $desc ); ?>" placeholder="<?php esc_attr_e( "Leave blank if you don't want to use Description", 'mymedic' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'type' ); ?>"><?php esc_html_e( 'Post Types:', 'mymedic' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" style="width:100%;">
				<option value="service" <?php selected( $type, 'service' ); ?>><?php esc_html_e( 'Services', 'mymedic' ); ?></option>
				<option value="department" <?php selected( $type, 'department' ); ?>><?php esc_html_e( 'Departments', 'mymedic' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php esc_html_e( 'Order By:', 'mymedic' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'orderby' ); ?>" name="<?php echo $this->get_field_name( 'orderby' ); ?>" style="width:100%;">
				<option value="name" <?php selected( $orderby, 'name' ); ?>><?php esc_html_e( 'Name', 'mymedic' ); ?></option>
				<option value="menu_order" <?php selected( $orderby, 'menu_order' ); ?>><?php esc_html_e( 'Order', 'mymedic' ); ?></option>
				<option value="date" <?php selected( $orderby, 'date' ); ?>><?php esc_html_e( 'Date', 'mymedic' ); ?></option>
				<option value="rand" <?php selected( $orderby, 'rand' ); ?>><?php esc_html_e( 'Random', 'mymedic' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'order' ); ?>"><?php esc_html_e( 'Order:', 'mymedic' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'order' ); ?>" name="<?php echo $this->get_field_name( 'order' ); ?>" style="width:100%;">
				<option value="asc" <?php selected( $order, 'asc' ); ?>><?php esc_html_e( 'Ascending', 'mymedic' ); ?></option>
				<option value="desc" <?php selected( $order, 'desc' ); ?>><?php esc_html_e( 'Descending', 'mymedic' ); ?></option>
			</select>
		</p>
	<?php
	}

}
