<?php
/**
 * Register custom customizer panels, sections and settings.
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * We register our custom customizer by using the hook.
 *
 * @since  1.0.0
 */
function mymedic_customizer_register() {

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// ======= Start Customizer Panels/Sections/Settings ======= //

	// General Panels and Sections
	$general_panel = 'general';

	$panels[] = array(
		'id'          => $general_panel,
		'title'       => __( 'General', 'mymedic' ),
		'description' => __( 'This panel is used for managing general section of your site.', 'mymedic' ),
		'priority'    => 10
	);

		// RSS
		$section = PREFIX . 'rss-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'RSS', 'mymedic' ),
			'priority'    => 100,
			'panel'       => $general_panel,
			'description' => __( 'If you fill the custom rss url below, it will replace the default.', 'mymedic' ),
		);
		$options[PREFIX . 'custom-rss'] = array(
			'id'           => PREFIX . 'custom-rss',
			'label'        => __( 'Custom RSS URL (eg. Feedburner)', 'mymedic' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);

		// Comment
		$section = PREFIX . 'comment-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Comments', 'mymedic' ),
			'priority'    => 110,
			'panel'       => $general_panel,
		);
		$options[PREFIX . 'page-comment'] = array(
			'id'           => PREFIX . 'page-comment',
			'label'        => __( 'Page Comment', 'mymedic' ),
			'section'      => $section,
			'type'         => 'switch',
			'default'      => 1
		);

		// Post Date Style
		$section = PREFIX . 'date-style-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Post Date Settings', 'mymedic' ),
			'priority'    => 120,
			'panel'       => $general_panel,
			'description' => __( 'Choose how date will be displayed on your posts', 'mymedic' ),

		);
		$options[PREFIX . 'post-date-style'] = array(
			'id'          => PREFIX . 'post-date-style',
			'label'       => __( 'Style', 'mymedic' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'absolute',
			'choices'     => array(
				'absolute' => __( 'Absolute (June 20, 2015 10:19 am)', 'mymedic' ),
				'relative' => __( 'Relative (1 week ago)', 'mymedic' )
			)
		);
		$options[PREFIX . 'post-date-type'] = array(
			'id'          => PREFIX . 'post-date-type',
			'label'       => __( 'Type', 'mymedic' ),
			'description' => __( "If you choose 'Modified Date', the last time you edit post will be displayed instead of the creation date", 'mymedic' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'published',
			'choices'     => array(
				'published' => __( 'Published Date', 'mymedic' ),
				'modified'  => __( 'Modified Date', 'mymedic' )
			)
		);

		// Social header
		$section = PREFIX . 'social-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Social', 'mymedic' ),
			'priority'    => 130,
			'panel'       => $general_panel
		);
		$options[PREFIX . 'twitter'] = array(
			'id'      => PREFIX . 'twitter',
			'label'   => __( 'Twitter URL', 'mymedic' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'facebook'] = array(
			'id'      => PREFIX . 'facebook',
			'label'   => __( 'Facebook URL', 'mymedic' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'gplus'] = array(
			'id'      => PREFIX . 'gplus',
			'label'   => __( 'Google Plus URL', 'mymedic' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'instagram'] = array(
			'id'      => PREFIX . 'instagram',
			'label'   => __( 'Instagram URL', 'mymedic' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'pinterest'] = array(
			'id'      => PREFIX . 'pinterest',
			'label'   => __( 'Pinterest URL', 'mymedic' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'linkedin'] = array(
			'id'      => PREFIX . 'linkedin',
			'label'   => __( 'LinkedIn URL', 'mymedic' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'tumblr'] = array(
			'id'      => PREFIX . 'tumblr',
			'label'   => __( 'Tumblr URL', 'mymedic' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'youtube'] = array(
			'id'      => PREFIX . 'youtube',
			'label'   => __( 'YouTube URL', 'mymedic' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'rss'] = array(
			'id'      => PREFIX . 'rss',
			'label'   => __( 'RSS URL', 'mymedic' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);

		// Newsletter script
		$section = PREFIX . 'newsletter-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Newsletter', 'mymedic' ),
			'priority'    => 140,
			'panel'       => $general_panel,
			'description' => __( 'Show newsletter form on the footer', 'mymedic' ),
		);
		$options[PREFIX . 'newsletter'] = array(
			'id'          => PREFIX . 'newsletter',
			'label'       => __( 'Show Newsletter', 'mymedic' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'newsletter-title'] = array(
			'id'      => PREFIX . 'newsletter-title',
			'label'   => esc_html__( 'Title', 'mymedic' ),
			'section' => $section,
			'type'    => 'text',
			'default' => esc_html__( 'Interested for our works and services?', 'mymedic' )
		);
		$options[PREFIX . 'newsletter-desc'] = array(
			'id'      => PREFIX . 'newsletter-desc',
			'label'   => esc_html__( 'Description', 'mymedic' ),
			'section' => $section,
			'type'    => 'textarea',
			'default' => esc_html__( 'The standard chunk of Lorem Ipsu from "de Finibus Bonorum et Malorum" by Cicero are also reproduced in their exact original form, accompanied. Donec id elit non mi porta gravida at eget metus.', 'mymedic' )
		);
		$options[PREFIX . 'newsletter-type'] = array(
			'id'      => PREFIX . 'newsletter-type',
			'label'   => esc_html__( 'Newsletter Type', 'mymedic' ),
			'section' => $section,
			'type'    => 'radio',
			'choices' => array(
				'feedburner' => esc_html__( 'FeedBurner', 'mymedic' ),
				'custom'     => esc_html__( 'Custom Code', 'mymedic' )
			),
			'default' => 'feedburner'
		);
		$options[PREFIX . 'newsletter-feedburner'] = array(
			'id'              => PREFIX . 'newsletter-feedburner',
			'label'           => esc_html__( 'FeedBurner ID', 'mymedic' ),
			'section'         => $section,
			'type'            => 'text',
			'default'         => esc_html__( 'ThemeJunkie', 'mymedic' ),
			'active_callback' => 'mymedic_newsletter_callback'
		);
		$options[PREFIX . 'newsletter-form'] = array(
			'id'                => PREFIX . 'newsletter-form',
			'label'             => esc_html__( 'Newsletter Form', 'mymedic' ),
			'section'           => $section,
			'type'              => 'textarea',
			'sanitize_callback' => 'mymedic_textarea_stripslashes',
			'default'           => '',
			'active_callback'   => 'mymedic_newsletter_callback'
		);

		// Footer Text
		$section = PREFIX . 'footer-text-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Footer Text', 'mymedic' ),
			'priority'    => 150,
			'panel'       => $general_panel,
		);
		$theme = wp_get_theme();
		$options[PREFIX . 'footer-text'] = array(
			'id'           => PREFIX . 'footer-text',
			'label'        => '',
			'description'  => __( 'Customize the footer text.', 'mymedic' ),
			'section'      => $section,
			'type'         => 'textarea',
			'default'      => sprintf( __( '&copy; %1$s %2$s &middot; %3$s %4$s by %5$s', 'mymedic' ),
				date( 'Y' ),
				'<a href="' . esc_url( home_url() ) . '">' . esc_attr( get_bloginfo( 'name' ) ) . '</a>',
				'<span class="themejunkie">',
				'<a href="' . esc_url( $theme->get( 'ThemeURI' ) ) . '">' . esc_attr( $theme->get( 'Name' ) ) . '</a>',
				'<a href="' . esc_url( $theme->get( 'AuthorURI' ) ) . '">' . esc_attr( $theme->get( 'Author' ) ) . '</a></span>' )
		);

		// Goole Maps API Key
		$section = PREFIX . 'google-maps-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Goole Maps API', 'mymedic' ),
			'priority'    => 155,
			'panel'       => $general_panel,
		);
		$options[PREFIX . 'google-maps-api-key'] = array(
			'id'          => PREFIX . 'google-maps-api-key',
			'label'       => esc_html__( 'Api Key', 'mymedic' ),
			'description' => sprintf( esc_html__( 'Please follow this link to %sget the Google API key%s.' ), '<a href="https://developers.google.com/maps/documentation/javascript/get-api-key">', '</a>' ),
			'section'     => $section,
			'type'        => 'text',
			'default'     => ''
		);


	// Header Panels and Sections
	$header_panel = 'header';

	$panels[] = array(
		'id'          => $header_panel,
		'title'       => __( 'Header', 'mymedic' ),
		'description' => __( 'This panel is used for managing header section of your site.', 'mymedic' ),
		'priority'    => 20
	);

		// Header Contact
		$section = PREFIX . 'contact-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Header Contact', 'mymedic' ),
			'priority'    => 30,
			'panel'       => $header_panel
		);
		$options[PREFIX . 'header-email'] = array(
			'id'          => PREFIX . 'header-email',
			'label'       => __( 'Contact Email', 'mymedic' ),
			'section'     => $section,
			'type'        => 'text',
			'default'     => 'support@theme-junkie.com'
		);
		$options[PREFIX . 'header-phone'] = array(
			'id'          => PREFIX . 'header-phone',
			'label'       => __( 'Contact Phone', 'mymedic' ),
			'section'     => $section,
			'type'        => 'text',
			'default'     => '+90 543 123 45 67'
		);

		// Header Image
		$section = PREFIX . 'header-image-section';
		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Header Image', 'mymedic' ),
			'priority'    => 40,
			'panel'       => $header_panel
		);
		$options[PREFIX . 'header-image'] = array(
			'id'          => PREFIX . 'header-image',
			'label'       => esc_html__( 'Header Image', 'mymedic' ),
			'description' => esc_html__( 'Recommended size: 1440 x 300', 'mymedic' ),
			'section'     => $section,
			'type'        => 'crop',
			'width'       => 1444,
			'height'      => 300,
			'default'     => trailingslashit( get_template_directory_uri() ) . 'assets/images/header1.jpg'
		);

		$options[PREFIX . 'header-department'] = array(
			'id'              => PREFIX . 'header-department',
			'label'           => esc_html__( 'Department Header Image', 'mymedic' ),
			'description'     => esc_html__( 'Recommended size: 1440 x 300', 'mymedic' ),
			'section'         => $section,
			'type'            => 'crop',
			'width'           => 1444,
			'height'          => 300,
			'default'         => trailingslashit( get_template_directory_uri() ) . 'assets/images/header4.jpg',
			'active_callback' => 'mymedic_post_types_callback'
		);

		$options[PREFIX . 'header-doctor'] = array(
			'id'              => PREFIX . 'header-doctor',
			'label'           => esc_html__( 'Doctor Header Image', 'mymedic' ),
			'description'     => esc_html__( 'Recommended size: 1440 x 300', 'mymedic' ),
			'section'         => $section,
			'type'            => 'crop',
			'width'           => 1444,
			'height'          => 300,
			'default'         => trailingslashit( get_template_directory_uri() ) . 'assets/images/header4.jpg',
			'active_callback' => 'mymedic_post_types_callback'
		);

		$options[PREFIX . 'header-portfolio'] = array(
			'id'              => PREFIX . 'header-portfolio',
			'label'           => esc_html__( 'Portfolio Header Image', 'mymedic' ),
			'description'     => esc_html__( 'Recommended size: 1440 x 300', 'mymedic' ),
			'section'         => $section,
			'type'            => 'crop',
			'width'           => 1444,
			'height'          => 300,
			'default'         => trailingslashit( get_template_directory_uri() ) . 'assets/images/header2.jpg',
			'active_callback' => 'mymedic_post_types_callback'
		);

		$options[PREFIX . 'header-testimonial'] = array(
			'id'              => PREFIX . 'header-testimonial',
			'label'           => esc_html__( 'Testimonial Header Image', 'mymedic' ),
			'description'     => esc_html__( 'Recommended size: 1440 x 300', 'mymedic' ),
			'section'         => $section,
			'type'            => 'crop',
			'width'           => 1444,
			'height'          => 300,
			'default'         => trailingslashit( get_template_directory_uri() ) . 'assets/images/header1.jpg',
			'active_callback' => 'mymedic_post_types_callback'
		);

		$options[PREFIX . 'header-service'] = array(
			'id'              => PREFIX . 'header-service',
			'label'           => esc_html__( 'Service Header Image', 'mymedic' ),
			'description'     => esc_html__( 'Recommended size: 1440 x 300', 'mymedic' ),
			'section'         => $section,
			'type'            => 'crop',
			'width'           => 1444,
			'height'          => 300,
			'default'         => trailingslashit( get_template_directory_uri() ) . 'assets/images/header1.jpg',
			'active_callback' => 'mymedic_post_types_callback'
		);

		/// Default Page Title for Blog
		$section = PREFIX . 'page-title-section';
		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Default Page Title', 'mymedic' ),
			'priority'    => 50,
			'panel'       => $header_panel,
			'description' => esc_html__( 'Default Page Title for Archive and Single Post Type', 'mymedic' ),
		);
		$options[PREFIX . 'default-title'] = array(
			'id'      => PREFIX . 'default-title',
			'label'   => esc_html__( 'Blog Page Title', 'mymedic' ),
			'section' => $section,
			'type'    => 'text',
			'default' => esc_html__( 'Blog', 'mymedic' )
		);
		$options[PREFIX . 'default-desc'] = array(
			'id'      => PREFIX . 'default-desc',
			'label'   => esc_html__( 'Blog Page Subtitle / Description', 'mymedic' ),
			'section' => $section,
			'type'    => 'textarea',
			'default' => esc_html__( 'Listed all our awesome blog posts, hospital news!', 'mymedic' )
		);

		$options[PREFIX . 'department-title'] = array(
			'id'              => PREFIX . 'department-title',
			'label'           => esc_html__( 'Department Title', 'mymedic' ),
			'section'         => $section,
			'type'            => 'text',
			'default'         => '',
			'active_callback' => 'mymedic_post_types_callback'
		);
		$options[PREFIX . 'department-desc'] = array(
			'id'              => PREFIX . 'department-desc',
			'label'           => esc_html__( 'Department Subtitle / Description', 'mymedic' ),
			'section'         => $section,
			'type'            => 'textarea',
			'default'         => esc_html__( 'Listed all our awesome departments, clinics!', 'mymedic' ),
			'active_callback' => 'mymedic_post_types_callback'
		);

		$options[PREFIX . 'doctor-title'] = array(
			'id'              => PREFIX . 'doctor-title',
			'label'           => esc_html__( 'Doctor Title', 'mymedic' ),
			'section'         => $section,
			'type'            => 'text',
			'default'         => '',
			'active_callback' => 'mymedic_post_types_callback'
		);
		$options[PREFIX . 'doctor-desc'] = array(
			'id'              => PREFIX . 'doctor-desc',
			'label'           => esc_html__( 'Doctor Subtitle / Description', 'mymedic' ),
			'section'         => $section,
			'type'            => 'textarea',
			'default'         => esc_html__( 'Listed all our awesome Doctors, Staffs and Nurses, special thanks for all the team!', 'mymedic' ),
			'active_callback' => 'mymedic_post_types_callback'
		);

		$options[PREFIX . 'portfolio-title'] = array(
			'id'              => PREFIX . 'portfolio-title',
			'label'           => esc_html__( 'Portfolio Title', 'mymedic' ),
			'section'         => $section,
			'type'            => 'text',
			'default'         => esc_html__( 'Our Gallery', 'mymedic' ),
			'active_callback' => 'mymedic_post_types_callback'
		);
		$options[PREFIX . 'portfolio-desc'] = array(
			'id'              => PREFIX . 'portfolio-desc',
			'label'           => esc_html__( 'Portfolio Subtitle / Description', 'mymedic' ),
			'section'         => $section,
			'type'            => 'textarea',
			'default'         => esc_html__( 'Listed all our awesome gallery photos!', 'mymedic' ),
			'active_callback' => 'mymedic_post_types_callback'
		);

		$options[PREFIX . 'testimonial-title'] = array(
			'id'              => PREFIX . 'testimonial-title',
			'label'           => esc_html__( 'Testimonial Title', 'mymedic' ),
			'section'         => $section,
			'type'            => 'text',
			'default'         => '',
			'active_callback' => 'mymedic_post_types_callback'
		);
		$options[PREFIX . 'testimonial-desc'] = array(
			'id'              => PREFIX . 'testimonial-desc',
			'label'           => esc_html__( 'Testimonial Subtitle / Description', 'mymedic' ),
			'section'         => $section,
			'type'            => 'textarea',
			'default'         => esc_html__( 'Listed below relatives of the patient comments, testimonials and clients!', 'mymedic' ),
			'active_callback' => 'mymedic_post_types_callback'
		);

		$options[PREFIX . 'service-title'] = array(
			'id'              => PREFIX . 'service-title',
			'label'           => esc_html__( 'Service Title', 'mymedic' ),
			'section'         => $section,
			'type'            => 'text',
			'default'         => '',
			'active_callback' => 'mymedic_post_types_callback'
		);
		$options[PREFIX . 'service-desc'] = array(
			'id'              => PREFIX . 'service-desc',
			'label'           => esc_html__( 'Service Subtitle / Description', 'mymedic' ),
			'section'         => $section,
			'type'            => 'textarea',
			'default'         => esc_html__( 'Listed below our trusted medical services from our hospital!', 'mymedic' ),
			'active_callback' => 'mymedic_post_types_callback'
		);

	// Colors Panel and Sections
	/* $color_panel = 'color';

	$panels[] = array(
		'id'          => $color_panel,
		'title'       => __( 'Color', 'mymedic' ),
		'description' => __( 'This panel is used for managing colors of your site.', 'mymedic' ),
		'priority'    => 20
	); */


	// Typography Sections
	$section = PREFIX . 'typography';
	$font_choices = customizer_library_get_font_choices();

		$sections[] = array(
			'id'       => $section,
			'title'    => __( 'Typography', 'mymedic' ),
			'description' => __( 'This panel is used for managing typography of your site.', 'mymedic' ),
			'priority' => 30
			// 'panel'    => $typo_panel
		);
		$options[PREFIX . 'custom-fonts'] = array(
			'id'          => PREFIX . 'custom-fonts',
			'label'       => __( 'Use Custom Fonts', 'mymedic' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 0
		);
		$options[PREFIX . 'primary-font'] = array(
			'id'              => PREFIX . 'primary-font',
			'label'           => __( 'Primary Font', 'mymedic' ),
			'section'         => $section,
			'type'            => 'select2',
			'choices'         => $font_choices,
			'default'         => 'Droid Serif',
			'active_callback' => 'mymedic_typography_callback'
		);
		$options[PREFIX . 'secondary-font'] = array(
			'id'              => PREFIX . 'secondary-font',
			'label'           => __( 'Secondary Font', 'mymedic' ),
			'section'         => $section,
			'type'            => 'select2',
			'choices'         => $font_choices,
			'default'         => 'Roboto',
			'active_callback' => 'mymedic_typography_callback'
		);
		$options[PREFIX . 'tertiary-font'] = array(
			'id'              => PREFIX . 'tertiary-font',
			'label'           => __( 'Tertiary Font', 'mymedic' ),
			'section'         => $section,
			'type'            => 'select2',
			'choices'         => $font_choices,
			'default'         => 'Roboto Slab',
			'active_callback' => 'mymedic_typography_callback'
		);


	// Content Panel and Sections
	$content_panel = 'layouts';

	$panels[] = array(
		'id'          => $content_panel,
		'title'       => __( 'Layouts', 'mymedic' ),
		'description' => __( 'This panel is used for managing several custom features/layouts of your site.', 'mymedic' ),
		'priority'    => 35
	);

		// Archive
		$section = PREFIX . 'archive-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Archive', 'mymedic' ),
			'priority'    => 10,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'archive-layout'] = array(
			'id'          => PREFIX . 'archive-layout',
			'label'       => esc_html__( 'Choose Archive Layout', 'mymedic' ),
			'section'     => $section,
			'type'        => 'radio',
			'default'     => 'std',
			'choices'     => array(
				'std'  => esc_html__( 'Standard', 'mymedic' ),
				'grid' => esc_html__( 'Grid', 'mymedic' ),
			)
		);

		// Posts
		$section = PREFIX . 'posts-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Posts', 'mymedic' ),
			'description' => __( 'Posts is single post page. Some also applied on archive post page.', 'mymedic' ),
			'priority'    => 20,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'post-meta-group'] = array(
			'id'          => PREFIX . 'post-meta-group',
			'label'       => __( 'Post Meta', 'mymedic' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'post-author'] = array(
				'id'          => PREFIX . 'post-author',
				'label'       => __( 'Show post author name', 'mymedic' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-date'] = array(
				'id'          => PREFIX . 'post-date',
				'label'       => __( 'Show post date', 'mymedic' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-view'] = array(
				'id'          => PREFIX . 'post-view',
				'label'       => __( 'Show entry views', 'mymedic' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-share'] = array(
				'id'          => PREFIX . 'post-share',
				'label'       => __( 'Show post share', 'mymedic' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
		$options[PREFIX . 'post-footer-group'] = array(
			'id'          => PREFIX . 'post-footer-group',
			'label'       => __( 'Category and Tag', 'mymedic' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'post-cat'] = array(
				'id'          => PREFIX . 'post-cat',
				'label'       => __( 'Show post categories', 'mymedic' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-tag'] = array(
				'id'          => PREFIX . 'post-tag',
				'label'       => __( 'Show post tags', 'mymedic' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);

		// Page
		$section = PREFIX . 'page-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Page', 'mymedic' ),
			'priority'    => 30,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'page-title'] = array(
			'id'          => PREFIX . 'page-title',
			'label'       => __( 'Show page title', 'mymedic' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

	// Maintenance Sections
	$section = PREFIX . 'maintenance';

		$sections[] = array(
			'id'       => $section,
			'title'    => __( 'Maintenance', 'mymedic' ),
			'description' => __( 'This panel is used for managing maintenance mode of your site.', 'mymedic' ),
			'priority' => 50
		);
		$options[PREFIX . 'maintenance-mode'] = array(
			'id'          => PREFIX . 'maintenance-mode',
			'label'       => __( 'Activate Maintenance Mode', 'mymedic' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 0
		);
		$options[PREFIX . 'maintenance-image'] = array(
			'id'              => PREFIX . 'maintenance-image',
			'label'           => esc_html__( 'Maintenance Background Image', 'mymedic' ),
			'description'     => esc_html__( 'Recommended size: 2000 x 1125', 'mymedic' ),
			'section'         => $section,
			'type'            => 'crop',
			'width'           => 2000,
			'height'          => 1125,
			'default'         => trailingslashit( get_template_directory_uri() ) . 'assets/images/parallax_01.jpg'
		);
		$options[PREFIX . 'maintenance-title'] = array(
			'id'      => PREFIX . 'maintenance-title',
			'label'   => esc_html__( 'Title', 'mymedic' ),
			'section' => $section,
			'type'    => 'text',
			'default' => esc_html__( 'Coming Soon', 'mymedic' )
		);
		$options[PREFIX . 'maintenance-desc'] = array(
			'id'                => PREFIX . 'maintenance-desc',
			'label'             => esc_html__( 'Description', 'mymedic' ),
			'section'           => $section,
			'type'              => 'textarea',
			'sanitize_callback' => 'mymedic_textarea_stripslashes',
			'default'           => __( 'Apologies!! We are really working hard towards to fix the problem!! <br>We will get back to you soon!! Keep in touch!!!', 'mymedic' )
		);
		$options[PREFIX . 'maintenance-newsletter'] = array(
			'id'          => PREFIX . 'maintenance-newsletter',
			'label'       => __( 'Show Subscribe Form', 'mymedic' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'maintenance-newsletter-type'] = array(
			'id'      => PREFIX . 'maintenance-newsletter-type',
			'label'   => esc_html__( 'Subscribe Form Type', 'mymedic' ),
			'section' => $section,
			'type'    => 'radio',
			'choices' => array(
				'feedburner' => esc_html__( 'FeedBurner', 'mymedic' ),
				'custom'     => esc_html__( 'Custom Code', 'mymedic' )
			),
			'default' => 'feedburner'
		);
		$options[PREFIX . 'maintenance-newsletter-feedburner'] = array(
			'id'              => PREFIX . 'maintenance-newsletter-feedburner',
			'label'           => esc_html__( 'FeedBurner ID', 'mymedic' ),
			'section'         => $section,
			'type'            => 'text',
			'default'         => esc_html__( 'ThemeJunkie', 'mymedic' ),
			'active_callback' => 'mymedic_newsletter_callback'
		);
		$options[PREFIX . 'maintenance-newsletter-form'] = array(
			'id'                => PREFIX . 'maintenance-newsletter-form',
			'label'             => esc_html__( 'Subscribe Form Code', 'mymedic' ),
			'section'           => $section,
			'type'              => 'textarea',
			'sanitize_callback' => 'mymedic_textarea_stripslashes',
			'default'           => '',
			'active_callback'   => 'mymedic_newsletter_callback'
		);

	// Advertisement Panel and Sections
	$ads_panel = 'advertisement';

	$panels[] = array(
		'id'       => $ads_panel,
		'title'    => __( 'Advertisement', 'mymedic' ),
		'priority' => 80
	);

		// Posts ads
		$section = PREFIX . 'posts-ads-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Posts', 'mymedic' ),
			'description' => __( 'Single post advertisement', 'mymedic' ),
			'priority'    => 10,
			'panel'       => $ads_panel,
		);
		$options[PREFIX . 'post-ads-before'] = array(
			'id'          => PREFIX . 'post-ads-before',
			'label'       => __( 'Ads Before Content', 'mymedic' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'post-ads-image-before'] = array(
				'id'           => PREFIX . 'post-ads-image-before',
				'label'        => __( 'Ads Image', 'mymedic' ),
				'description'  => __( 'Upload your ads image then put the url in the setting below.', 'mymedic' ),
				'section'      => $section,
				'type'         => 'media',
				'default'      => '',
			);
			$options[PREFIX . 'post-ads-url-before'] = array(
				'id'           => PREFIX . 'post-ads-url-before',
				'label'        => __( 'Ads URL', 'mymedic' ),
				'description'  => __( 'Put the ads url in the box below.', 'mymedic' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);
			$options[PREFIX . 'post-ads-custom-before'] = array(
				'id'                => PREFIX . 'post-ads-custom-before',
				'label'             => __( 'Or', 'mymedic' ),
				'description'       => __( 'Pur you custom ads code (eg. adsense) in the box below.', 'mymedic' ),
				'section'           => $section,
				'type'              => 'textarea',
				'sanitize_callback' => 'mymedic_textarea_stripslashes',
				'default'           => ''
			);
		$options[PREFIX . 'post-ads-after'] = array(
			'id'          => PREFIX . 'post-ads-after',
			'label'       => __( 'Ads After Content', 'mymedic' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'post-ads-image-after'] = array(
				'id'           => PREFIX . 'post-ads-image-after',
				'label'        => __( 'Ads Image', 'mymedic' ),
				'description'  => __( 'Upload your ads image then put the url in the setting below.', 'mymedic' ),
				'section'      => $section,
				'type'         => 'media',
				'default'      => '',
			);
			$options[PREFIX . 'post-ads-url-after'] = array(
				'id'           => PREFIX . 'post-ads-url-after',
				'label'        => __( 'Ads URL', 'mymedic' ),
				'description'  => __( 'Put the ads url in the box below.', 'mymedic' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);
			$options[PREFIX . 'post-ads-custom-after'] = array(
				'id'                => PREFIX . 'post-ads-custom-after',
				'label'             => __( 'Or', 'mymedic' ),
				'description'       => __( 'Pur you custom ads code (eg. adsense) in the box below.', 'mymedic' ),
				'section'           => $section,
				'type'              => 'textarea',
				'sanitize_callback' => 'mymedic_textarea_stripslashes',
				'default'           => ''
			);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

}
add_action( 'init', 'mymedic_customizer_register' );

/**
 * Callback for Typography
 */
function mymedic_typography_callback( $control ) {
    if ( 1 === $control->manager->get_setting( PREFIX . 'custom-fonts' )->value() ) {
        return true;
    } else {
        return false;
    }
}

/**
 * Callback for Newsletter
 */
function mymedic_newsletter_callback( $control ) {
	$id = $control->id;

	// footer newsletter
	$value = $control->manager->get_setting( PREFIX . 'newsletter-type' )->value();
	if ( ( PREFIX . 'newsletter-feedburner' == $id ) && ( 'feedburner' == $value ) ) return true;
	if ( ( PREFIX . 'newsletter-form' == $id ) && ( 'custom' == $value ) ) return true;

	// maintenance newsletter
	$value = $control->manager->get_setting( PREFIX . 'maintenance-newsletter-type' )->value();
	if ( ( PREFIX . 'maintenance-newsletter-feedburner' == $id ) && ( 'feedburner' == $value ) ) return true;
	if ( ( PREFIX . 'maintenance-newsletter-form' == $id ) && ( 'custom' == $value ) ) return true;

	return false;
}

/**
 * Callback for Post Type
 */
function mymedic_post_types_callback( $control ) {
	$id = $control->id;

	// Department Post Type
	if ( ( ( PREFIX . 'header-department' == $id ) || ( PREFIX . 'department-title' == $id ) || ( PREFIX . 'department-desc' == $id ) )
		&& ( post_type_exists( 'department') ) )
		return true;

	// Doctor Post Type
	if ( ( ( PREFIX . 'header-doctor' == $id ) || ( PREFIX . 'doctor-title' == $id ) || ( PREFIX . 'doctor-desc' == $id ) )
		&& ( post_type_exists( 'doctor') ) )
		return true;

	// Portfolio Post Type
	if ( ( ( PREFIX . 'header-portfolio' == $id ) || ( PREFIX . 'portfolio-title' == $id ) || ( PREFIX . 'portfolio-desc' == $id ) )
		&& ( post_type_exists( 'jetpack-portfolio') ) )
		return true;

	// Testimonial Post Type
	if ( ( ( PREFIX . 'header-testimonial' == $id ) || ( PREFIX . 'testimonial-title' == $id ) || ( PREFIX . 'testimonial-desc' == $id ) )
		&& ( post_type_exists( 'jetpack-testimonial') ) )
		return true;

	// Service Post Type
	if ( ( ( PREFIX . 'header-service' == $id ) || ( PREFIX . 'service-title' == $id ) || ( PREFIX . 'service-desc' == $id ) )
		&& ( post_type_exists( 'service') ) )
		return true;

	return false;
}
