<?php
/**
 * Enqueue scripts and styles.
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Loads the theme styles & scripts.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/wp_enqueue_script
 * @link  http://codex.wordpress.org/Function_Reference/wp_enqueue_style
 */
function mymedic_enqueue() {

	// Enqueue Fonts
	if ( 0 == mymedic_mod( PREFIX . 'custom-fonts' ) ) {
		wp_enqueue_style( 'mymedic-fonts', mymedic_fonts_url(), array(), null );
	}

	// Load plugins stylesheet
	wp_enqueue_style( 'mymedic-plugins-style', trailingslashit( get_template_directory_uri() ) . 'assets/css/plugins.min.css' );

	// if WP_DEBUG and/or SCRIPT_DEBUG turned on, load the unminified styles & script.
	if ( ! is_child_theme() && WP_DEBUG || SCRIPT_DEBUG ) {

		// Load stylesheet info
		wp_enqueue_style( 'mymedic-style', get_stylesheet_uri() );

		// Load custom stylesheet
		wp_enqueue_style( 'mymedic-custom', trailingslashit( get_template_directory_uri() ) . 'assets/css/custom.css' );

		// Load custom js plugins.
		wp_enqueue_script( 'mymedic-plugins', trailingslashit( get_template_directory_uri() ) . 'assets/js/plugins.min.js', array( 'jquery' ), null, true );

		// Load custom js methods.
		wp_enqueue_script( 'mymedic-main', trailingslashit( get_template_directory_uri() ) . 'assets/js/main.js', array( 'jquery' ), null, true );

	} else {

		// Load main stylesheet
		wp_enqueue_style( 'mymedic-style', trailingslashit( get_template_directory_uri() ) . $version . 'style.min.css' );

		// Load custom js plugins.
		wp_enqueue_script( 'mymedic-scripts', trailingslashit( get_template_directory_uri() ) . 'assets/js/mymedic.min.js', array( 'jquery' ), null, true );

	}

	// Contact
	if ( is_page_template( 'page-templates/contact.php' ) ) {
		// get metabox value
		$infobox = get_post_meta( get_the_ID(), 'tj_contact_infobox', true );
		$location = get_post_meta( get_the_ID(), 'tj_contact_maps', true );

		if ( $location ) {
			// google maps API
			wp_enqueue_script( 'mymedic-maps', 'https://maps.googleapis.com/maps/api/js', array(), null, false );
			// minimize from devs/map.js
			wp_enqueue_script( 'mymedic-contact', trailingslashit( get_template_directory_uri() ) . 'assets/js/map.min.js', array( 'jquery' ), null, true );

			// pass var to js
			wp_localize_script( 'mymedic-contact', 'mymedic',
				array(
					'infobox' => isset( $infobox ) ? $infobox : '',
					'lat'     => $location['lat'],
					'lng'     => $location['lng'],
					'icon'    => trailingslashit( get_stylesheet_directory_uri() ) . 'assets/images/marker.png'
				)
			);
		}
	}

	// Portfolio
	if ( 'jetpack-portfolio' == get_post_type() ) {
		wp_enqueue_style( 'mymedic-prettyphoto', trailingslashit( get_template_directory_uri() ) . 'assets/css/prettyPhoto.min.css' );

		// merge from: isotope.js, imagesloaded.pkgd.js, jquery.prettyPhoto.js, masonry-one.js
		wp_enqueue_script( 'mymedic-portfolio', trailingslashit( get_template_directory_uri() ) . 'assets/js/portfolio.min.js', array( 'jquery' ), null, true );
	}

	// If child theme is active, load the stylesheet.
	if ( is_child_theme() ) {
		wp_enqueue_style( 'mymedic-child-style', get_stylesheet_uri() );
	}

	// Load comment-reply script.
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// Load HTML5 Shiv
	wp_enqueue_script( 'mymedic-html5', trailingslashit( get_template_directory_uri() ) . 'assets/js/html5shiv.min.js', array( 'jquery' ), null, false );
	wp_script_add_data( 'mymedic-html5', 'conditional', 'lte IE 9' );

	// Load Respond.js
	wp_enqueue_script( 'mymedic-respond', '//oss.maxcdn.com/respond/1.4.2/respond.min.js', array(), null, false );
	wp_script_add_data( 'mymedic-respond', 'conditional', 'lte IE 9' );

}
add_action( 'wp_enqueue_scripts', 'mymedic_enqueue' );

/**
 * Enqueue jQuery UI css for Ninja Form
 */
function mymedic_enqueue_jqueryui() {
	// for datepicker; enqueue after Ninja Forms CSS
	wp_enqueue_style( 'mymedic-jquery-ui', trailingslashit( get_template_directory_uri() ) . 'assets/css/jquery-ui.css', array( 'ninja-forms-display' ) );
}
add_action( 'ninja_forms_display_css', 'mymedic_enqueue_jqueryui', 20 );

/**
 * Apple Touch Icons
 */
function mymedic_apple_icons() {
	?>
<link rel="apple-touch-icon" href="<?php echo esc_url( trailingslashit( get_stylesheet_directory_uri() ) . 'assets/images/apple-touch-icon.png' ); ?>" />
<link rel="apple-touch-icon" sizes="57x57" href="<?php echo esc_url( trailingslashit( get_stylesheet_directory_uri() ) . 'assets/images/apple-touch-icon-57x57.png' ); ?>">
<link rel="apple-touch-icon" sizes="72x72" href="<?php echo esc_url( trailingslashit( get_stylesheet_directory_uri() ) . 'assets/images/apple-touch-icon-72x72.png' ); ?>">
<link rel="apple-touch-icon" sizes="76x76" href="<?php echo esc_url( trailingslashit( get_stylesheet_directory_uri() ) . 'assets/images/apple-touch-icon-76x76.png' ); ?>">
<link rel="apple-touch-icon" sizes="114x114" href="<?php echo esc_url( trailingslashit( get_stylesheet_directory_uri() ) . 'assets/images/apple-touch-icon-114x114.png' ); ?>">
<link rel="apple-touch-icon" sizes="120x120" href="<?php echo esc_url( trailingslashit( get_stylesheet_directory_uri() ) . 'assets/images/apple-touch-icon-120x120.png' ); ?>">
<link rel="apple-touch-icon" sizes="144x144" href="<?php echo esc_url( trailingslashit( get_stylesheet_directory_uri() ) . 'assets/images/apple-touch-icon-144x144.png' ); ?>">
<link rel="apple-touch-icon" sizes="152x152" href="<?php echo esc_url( trailingslashit( get_stylesheet_directory_uri() ) . 'assets/images/apple-touch-icon-152x152.png' ); ?>">
	<?php
}
add_action( 'wp_head', 'mymedic_apple_icons' );
