<?php
/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
if ( ! function_exists( 'mymedic_site_branding' ) ) :
/**
 * Site branding for the site.
 *
 * Display site title by default, but user can change it with their custom logo.
 * They can upload it on Customizer page.
 *
 * @since  1.0.0
 */
function mymedic_site_branding() {

	// Get the customizer value.
	$logo_id  = get_theme_mod( 'custom_logo' );

	// Check if logo available, then display it.
	if ( $logo_id ) :
		echo '<div id="logo" itemscope itemtype="http://schema.org/Brand">' . "\n";
			echo '<a class="navbar-brand" href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home">' . "\n";
				echo '<img itemprop="logo" src="' . esc_url( wp_get_attachment_url( $logo_id ) ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" />' . "\n";
			echo '</a>' . "\n";
		echo '</div>' . "\n";

	// If not, then display the Site Title and Site Description.
	else :
		echo '<div id="logo">'. "\n";
			echo '<h1 class="site-title" ' . hybrid_get_attr( 'site-title' ) . '><a class="navbar-brand" href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home"><span itemprop="headline">' . esc_attr( get_bloginfo( 'name' ) ) . '</span></a></h1>'. "\n";
			echo '<h2 class="site-description" ' . hybrid_get_attr( 'site-description' ) . '>' . esc_attr( get_bloginfo( 'description' ) ) . '</h2>';
		echo '</div>'. "\n";
	endif;

}
endif;

if ( ! function_exists( 'mymedic_social_icons' ) ) :
/**
 * Header social
 */
function mymedic_social_icons() {

	// Get the customizer data
	$tw        = mymedic_mod( PREFIX . 'twitter' );
	$fb        = mymedic_mod( PREFIX . 'facebook' );
	$gplus     = mymedic_mod( PREFIX . 'gplus' );
	$instagram = mymedic_mod( PREFIX . 'instagram' );
	$pinterest = mymedic_mod( PREFIX . 'pinterest' );
	$linkedin  = mymedic_mod( PREFIX . 'linkedin' );
	$tumblr    = mymedic_mod( PREFIX . 'tumblr' );
	$youtube   = mymedic_mod( PREFIX . 'youtube' );
	$rss       = mymedic_mod( PREFIX . 'rss' );

	// Display the data
	if ( $tw || $fb || $gplus || $instagram || $pinterest || $linkedin || $tumblr || $youtube || $rss ) {

		echo '<li class="hidden-xs hidden-sm">';
		echo '<div class="social">';
			if ( $tw ) {
				echo '<a href="' . esc_url( $tw ) . '" data-tooltip="tooltip" data-placement="bottom" title="Twitter"><i class="fa fa-twitter"></i></a> ';
			}
			if ( $fb ) {
				echo '<a href="' . esc_url( $fb ) . '" data-tooltip="tooltip" data-placement="bottom" title="Facebook"><i class="fa fa-facebook"></i></a> ';
			}
			if ( $gplus ) {
				echo '<a href="' . esc_url( $gplus ) . '" data-tooltip="tooltip" data-placement="bottom" title="Google Plus"><i class="fa fa-google-plus"></i></a> ';
			}
			if ( $instagram ) {
				echo '<a href="' . esc_url( $instagram ) . '" data-tooltip="tooltip" data-placement="bottom" title="Instagram"><i class="fa fa-instagram"></i></a> ';
			}
			if ( $pinterest ) {
				echo '<a href="' . esc_url( $pinterest ) . '" data-tooltip="tooltip" data-placement="bottom" title="Pinterest"><i class="fa fa-pinterest"></i></a> ';
			}
			if ( $linkedin ) {
				echo '<a href="' . esc_url( $linkedin ) . '" data-tooltip="tooltip" data-placement="bottom" title="LinkedIn"><i class="fa fa-linkedin"></i></a> ';
			}
			if ( $tumblr ) {
				echo '<a href="' . esc_url( $tumblr ) . '" data-tooltip="tooltip" data-placement="bottom" title="Tumblr"><i class="fa fa-tumblr"></i></a> ';
			}
			if ( $youtube ) {
				echo '<a href="' . esc_url( $youtube ) . '" data-tooltip="tooltip" data-placement="bottom" title="YouTube"><i class="fa fa-youtube"></i></a> ';
			}
			if ( $rss ) {
				echo '<a href="' . esc_url( $rss ) . '" data-tooltip="tooltip" data-placement="bottom" title="RSS Feeds"><i class="fa fa-rss"></i></a>';
			}
		echo '</div><!-- end social -->';
		echo '</li>';

	}

}
endif;

if ( ! function_exists( 'mymedic_featured_image' ) ) :
/**
 * Featured Image
 * $args = array( $size, $default, $link, $share )
 *
 * @since  1.0.0
 */
function mymedic_featured_image( $args ) {

	$size = 'post-thumbnail';
	// for no sidebar
	if ( current_theme_supports( 'theme-layouts' ) && ! is_admin() ) {
		if ( 'layout-1c' == theme_layouts_get_layout() ) {
			$size = 'large';
		}
	}

	$defaults = array(
		'size' => $size,
		'default' => false,
		'link' => true
	);

	$args = wp_parse_args( $args, $defaults );
	extract( $args );

	if ( $default || has_post_thumbnail() ) :
	?>
		<div class="blog-image" itemprop="image" itemscope itemtype="https://schema.org/ImageObject">
			<?php if ( $link ) : ?><a class="post-link" href="<?php the_permalink(); ?>"><?php endif; ?>
				<?php if ( has_post_thumbnail() ) : ?>
					<?php the_post_thumbnail( $size, array( 'class' => 'img-responsive', 'alt' => esc_attr( get_the_title() ) ) ); ?>
					<meta itemprop="url" content="<?php echo esc_url( wp_get_attachment_url( get_post_thumbnail_id( get_the_ID() ) ) ); ?>">
				<?php else: ?>
					<img class="img-responsive" src="<?php echo esc_url( 'http://placehold.it/' . $default . '&amp;text=' . urlencode( get_the_title() ) ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>" />
					<meta itemprop="url" content="<?php echo esc_url( 'http://placehold.it/' . $default ); ?>">
				<?php endif; ?>
			<?php if ( $link ) : ?></a><?php endif; ?>
			<meta itemprop="width" content="750">
			<meta itemprop="height" content="515">
		</div><!-- .blog-image -->
	<?php
	endif;
}
endif;

if ( ! function_exists( 'mymedic_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since 1.0.0
 */
function mymedic_posted_on() {
	$date   = mymedic_mod( PREFIX . 'post-date' );

	if ( ! $date )
		return;
	?>

	<meta <?php hybrid_attr( 'entry-published' ); ?>/>
	<meta itemprop="dateModified" content="<?php echo esc_attr( get_the_modified_date( 'c' ) ); ?>" title="<?php echo esc_attr( get_the_modified_time( _x( 'l, F j, Y, g:i a', 'post time format', 'mymedic' ) ) ); ?>" />

	<?php
	// Get the date type and style
	$date_type  = mymedic_mod( PREFIX . 'post-date-type' );
	$date_style = mymedic_mod( PREFIX . 'post-date-style' );

	if ( 'published' == $date_type ) {
		$datestamp = get_the_date();
		$timestamp = get_the_time( 'U' );
		$datetime  = get_the_date( 'c' );
	} else {
		$datestamp = get_the_modified_date();
		$timestamp = get_the_modified_time( 'U' );
		$datetime  = get_the_modified_date( 'c' );
	}

	if ( 'absolute' == $date_style ) {
		$date_string = esc_html( $datestamp );
	} else {
		$date_string = sprintf( __( '%s ago', 'mymedic' ), human_time_diff( $timestamp, current_time( 'timestamp' ) ) );
	}

	$time_string = sprintf( '<time datetime="%1$s">%2$s</time>',
		esc_attr( $datetime ),
		$date_string
	);

	printf( _x( '<span class="posted-on"><i class="fa fa-calendar"></i> %1$s</span>', 'post date', 'mymedic' ),
		sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>',
			esc_url( get_permalink() ),
			$time_string )
	);
}
endif;

if ( ! function_exists( 'mymedic_entry_author' ) ) :
/**
 * Entry Author
 */
function mymedic_entry_author() {

	$author = mymedic_mod( PREFIX . 'post-author' );

	if ( ! $author )
		return;

	printf( '<span class="post-author vcard" ' . hybrid_get_attr( 'entry-author' ) . '><i class="fa fa-user"></i> <a class="url fn n" href="%1$s" itemprop="url"><meta itemprop="name" content="%2$s">%3$s</a></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_html( get_the_author() ),
		esc_html( get_the_author() )
	);
}
endif;

if ( ! function_exists( 'mymedic_entry_comment' ) ) :
/**
 * Comment count
 *
 * @since  1.0.0
 */
function mymedic_entry_comment() {

	if ( ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) ) : ?>
		<span class="entry-comments">
			<i class="fa fa-comments"></i>
			<?php comments_popup_link( esc_html__( '0 Comment', 'mymedic' ), esc_html__( '1 Comment', 'mymedic' ), esc_html__( '% Comments', 'mymedic' ) ); ?>
		</span>
	<?php endif;
}
endif;

if ( ! function_exists( 'mymedic_entry_category' ) ) :
/**
 * Entry Category
 */
function mymedic_entry_category() {

	// bail out if not 'Post'
	if ( 'post' != get_post_type() )
		return;

	$cat      = mymedic_mod( PREFIX . 'post-cat' );
	$category = get_the_category( get_the_ID() );

	if ( $cat && $category ) {
		?>
		<span class="entry-category" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
			<a class="category_title" href="<?php echo esc_url( get_category_link( $category[0]->term_id ) ); ?>"><?php echo esc_html( $category[0]->name ); ?></a>
		</span><!-- .entry-category -->
		<?php
	}
}
endif;

if ( ! function_exists( 'mymedic_categorized_blog' ) ) :
/**
 * Returns true if a blog has more than 1 category.
 *
 * @since  1.0.0
 * @return bool
 */
function mymedic_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'mymedic_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'mymedic_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so mymedic_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so mymedic_categorized_blog should return false.
		return false;
	}
}
endif;

if ( ! function_exists( 'mymedic_category_transient_flusher' ) ) :
/**
 * Flush out the transients used in mymedic_categorized_blog.
 *
 * @since 1.0.0
 */
function mymedic_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'mymedic_categories' );
}
endif;
add_action( 'edit_category', 'mymedic_category_transient_flusher' );
add_action( 'save_post',     'mymedic_category_transient_flusher' );

if ( ! function_exists( 'mymedic_entry_tag' ) ) :
/**
 * Entry Tags
 */
function mymedic_entry_tag() {

	// bail out if not 'Post'
	if ( 'post' != get_post_type() )
		return;

	$tag  = mymedic_mod( PREFIX . 'post-tag' );
	$tags = get_the_tags();
	if ( $tag && $tags ) :
	?>
		<span class="tag-links" <?php hybrid_attr( 'entry-terms', 'post_tag' ); ?>>
			<i class="fa fa-tags"></i>
			<?php the_tags( '' ); ?>
			<?php /* foreach( $tags as $tag ) : ?>
				<a href="<?php echo esc_url( get_tag_link( $tag->term_id ) ); ?>"><?php echo esc_attr( $tag->name ); ?></a>
			<?php endforeach; */ ?>
		</span>
	<?php endif;
}
endif;

if ( ! function_exists( 'mymedic_entry_view' ) ) :
/**
 * Entry Views
 */
function mymedic_entry_view() {
	$view  = mymedic_mod( PREFIX . 'post-view' );
	if ( $view && function_exists( 'entry_views_get' ) ) :
	?>
		<span>
			<i class="fa fa-eye"></i>
			<?php echo esc_html( entry_views_get( array( 'after' => __( ' Views', 'mymedic' ) ) ) ); ?>
		</span>
	<?php endif;
}
endif;

if ( ! function_exists( 'mymedic_entry_share' ) ) :
/**
 * Social share.
 *
 * @since 1.0.0
 */
function mymedic_entry_share() {

	// Get the data set in customizer
	$share  = mymedic_mod( PREFIX . 'post-share' );

	if ( $share == 0 ) {
		return;
	}
	?>
		<div class="entry-share">
			<a class="icon-twitter" href="https://twitter.com/intent/tweet?text=<?php echo esc_attr( urlencode( get_the_title( get_the_ID() ) ) ); ?>&amp;url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-twitter"></i> <span><?php _ex( 'Tweet', 'entry share', 'mymedic' ); ?></span></a>
			<a class="icon-facebook" href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-facebook"></i> <span><?php _ex( 'Like', 'entry share', 'mymedic' ); ?></span></a>
			<a class="icon-google-plus" href="https://plus.google.com/share?url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-google-plus"></i> <span><?php _ex( 'Share', 'entry share', 'mymedic' ); ?></span></a>
			<a class="icon-linkedin" href="https://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>&amp;title=<?php echo esc_attr( urlencode( get_the_title( get_the_ID() ) ) ); ?>" target="_blank"><i class="fa fa-linkedin"></i> <span><?php _ex( 'Share', 'entry share', 'mymedic' ); ?></span></a>
			<a class="icon-pinterest" href="https://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>&amp;media=<?php echo urlencode( wp_get_attachment_url( get_post_thumbnail_id( get_the_ID() ) ) ); ?>" target="_blank"><i class="fa fa-pinterest"></i> <span><?php _ex( 'Pin it', 'entry share', 'mymedic' ); ?></span></a>
			<a class="icon-envelope" href="mailto:?subject=<?php echo esc_url( urlencode( '[' . get_bloginfo( 'name' ) . '] ' . get_the_title( get_the_ID() ) ) ); ?>&amp;body=<?php echo esc_url( urlencode( get_permalink( get_the_ID() ) ) ); ?>"><i class="fa fa-envelope"></i> <span><?php _ex( 'Email', 'entry share', 'mymedic' ); ?></span></a>
		</div>
	<?php
}
endif;

if ( ! function_exists( 'mymedic_entry_publisher' ) ) :
/**
 * Schema.org publisher
 */
function mymedic_entry_publisher() {
	?>
	<div itemprop="publisher" itemscope itemtype="https://schema.org/Organization">
		<div itemprop="logo" itemscope itemtype="https://schema.org/ImageObject">
			<?php
			$logo_id = get_theme_mod( 'custom_logo' );
			if ( $logo_id ) {
				$logo_url = wp_get_attachment_url( $logo_id );
			} else {
				$logo_url = trailingslashit( get_template_directory_uri() ) . 'assets/images/logo.png';
			}
			?>
			<meta itemprop="url" content="<?php echo esc_url( $logo_url ); ?>">
			<meta itemprop="width" content="212">
			<meta itemprop="height" content="56">
		</div>
		<meta itemprop="name" content="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">
	</div>
	<?php
}
endif;

if ( ! function_exists( 'mymedic_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since  1.0.0
 */
function mymedic_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<div <?php comment_class( 'media' ); ?> id="comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<div class="media-body">
			<p <?php hybrid_attr( 'comment-content' ); ?>><?php _e( 'Pingback:', 'mymedic' ); ?> <span <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php comment_author_link(); ?></span></span> <?php edit_comment_link( __( '(Edit)', 'mymedic' ), '<span class="edit-link">', '</span>' ); ?></p>
		</div>
	<?php
			break;
		default :
		// Proceed with normal comments.
	?>
	<?php
		global $comment_depth;
		$comment_classes = ( 1 < $comment_depth ) ? 'media comment-reply' : 'media';
	?>
	<div <?php comment_class( $comment_classes ); ?> id="comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>

		<div class="media-left">
			<?php if ( get_comment_author_url() ) : ?><a href="<?php echo esc_url( get_comment_author_url() ); ?>"><?php endif; ?>
				<?php echo get_avatar( $comment, apply_filters( 'mymedic_comment_avatar_size', 65 ) ); ?>
			<?php if ( get_comment_author_url() ) : ?></a><?php endif; ?>
		</div>

		<div class="media-body">
			<h4 class="media-heading">
				<span class="name" <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php echo get_comment_author_link(); ?></span></span>
				<?php echo mymedic_comment_author_badge(); ?>
			</h4>

			<div class="time-comment clearfix">
				<?php
					$edit_comment_link = '';
					if ( get_edit_comment_link() )
						$edit_comment_link = sprintf( __( '&middot; %1$sEdit%2$s', 'mymedic' ), '<a href="' . get_edit_comment_link() . '" title="' . esc_attr__( 'Edit Comment', 'mymedic' ) . '">', '</a>' );

					printf( '<small class="pull-left"><a href="%1$s" ' . hybrid_get_attr( 'comment-permalink' ) . '><time datetime="%2$s" ' . hybrid_get_attr( 'comment-published' ) . '>%3$s</time></a> %4$s</small>',
						esc_url( get_comment_link( $comment->comment_ID ) ),
						get_comment_time( 'c' ),
						/* translators: 1: date, 2: time */
						sprintf( __( '%1$s at %2$s', 'mymedic' ), get_comment_date(), get_comment_time() ),
						$edit_comment_link
					);
				?>
				<?php
					$reply_class = 'pull-right btn btn-primary btn-xs';
					echo preg_replace( '/comment-reply-link/', 'comment-reply-link ' . $reply_class, get_comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'mymedic' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ), 1 );
				?>
			</div><!-- end time-comment -->

			<div class="comment-content comment-entry" <?php hybrid_attr( 'comment-content' ); ?>>
				<?php if ( '0' == $comment->comment_approved ) : ?>
					<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'mymedic' ); ?></p>
				<?php endif; ?>
				<?php comment_text(); ?>
			</div><!-- .comment-content -->
		</div><!-- .media-body -->
	<!-- </div> #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;

if ( ! function_exists( 'mymedic_comment_author_badge' ) ) :
/**
 * Custom badge for post author comment
 *
 * @since  1.0.0
 */
function mymedic_comment_author_badge() {

	// Set up empty variable
	$output = '';

	// Get comment classes
	$classes = get_comment_class();

	if ( in_array( 'bypostauthor', $classes ) ) {
		$output = '<span class="author-badge">' . __( 'Author', 'mymedic' ) . '</span>';
	}

	// Display the badge
	return apply_filters( 'mymedic_comment_author_badge', $output );
}
endif;

/**
 * Custom comment form fields.
 *
 * @since  1.0.0
 * @param  array $fields
 * @return array
 */
function mymedic_comment_form_fields( $fields, $args = array() ) {

	$args = wp_parse_args( $args );
	if ( ! isset( $args['format'] ) )
		$args['format'] = current_theme_supports( 'html5', 'comment-form' ) ? 'html5' : 'xhtml';

	$commenter = wp_get_current_commenter();
	$req       = get_option( 'require_name_email' );
	$aria_req  = ( $req ? " aria-required='true'" : '' );
	$html5     = 'html5' === $args['format'];

	$fields['author'] = '<input class="form-control" id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" placeholder="' . __( 'Your Name', 'mymedic' ) . ( $req ? ' *' : '' ) . '"' . $aria_req . ' />';

	$fields['email'] = '<input class="form-control" id="email" name="email" ' . ( $html5 ? 'type="email"' : 'type="text"' ) . ' value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" placeholder="' . esc_attr__( 'Your Email', 'mymedic' ) . ( $req ? ' *' : '' ) . '"' . $aria_req . ' />';

	$fields['url'] = '<input class="form-control" id="url" name="url" ' . ( $html5 ? 'type="url"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" placeholder="' . esc_attr__( 'Your Website', 'mymedic' ) . '" />';

	return $fields;

}
add_filter( 'comment_form_default_fields', 'mymedic_comment_form_fields' );

if ( ! function_exists( 'mymedic_get_first_image' ) ) :
/**
 * Return an HTML img tag for the first image in a post content. Used to draw
 * the content for posts of the “image” format.
 * http://css-tricks.com/snippets/wordpress/get-the-first-image-from-a-post/#comment-1582091 --> not working
 * http://www.wprecipes.com/how-to-get-the-first-image-from-the-post-and-display-it
 *
 * @return string An HTML img tag for the first image in a post content.
 */
function mymedic_get_first_image( $size = 'full', $echo = true ) {

	// TO-DO: handle when $echo is false
	if ( has_post_thumbnail() && $echo ) {
		return mymedic_featured_image( array( 'size' => $size ) );
	}

	// Expose information about the current post.
	global $post;

	// We'll trap to see if this stays empty later in the function.
	$src = '';

	// Grab all img src's in the post content
	// $output = preg_match_all( '//i', $post->post_content, $matches ); // not working
	$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);

	// Grab the first img src returned by our regex.
	// if ( ! isset ( $matches[1][0] ) ) { return false; }
	// $src = $matches[1][0];

	// Grab the first <img> complete markup returned by our regex.
	if ( ! isset ( $matches[0][0] ) ) { return false; }
	$src = $matches[0][0];

	// Make sure there's still something worth outputting after sanitization.
	if ( empty( $src ) ) { return false; }

	$src = preg_replace( '/class="/', '/class="img-responsive ', $src );

	// add wrapper
	$content = '<div class="entry-image clearfix">';
		$content .= '<a class="img-link" href="' . get_the_permalink() . '">';
			$content .= $src;
		$content .= '</a>';
	$content .= '</div>';

	// choose whether to echo the result or return it as variable
	if ( true == $echo )
		echo $content;
	else
		return $src;

}
endif;

if ( ! function_exists( 'mymedic_get_format_gallery' ) ) :
/**
 * Get the [gallery] shortcode from the post content and display it on index page. It require
 * gallery ids [gallery ids=1,2,3,4] to display it as thumbnail slideshow. If no ids exist it
 * just display it as mymedic [gallery] markup.
 *
 * If no [gallery] shortcode found in the post content, get the attached images to the post and
 * display it as slideshow.
 *
 * @since  1.0.0
 * @uses   get_post_gallery() to get the gallery in the post content.
 * @uses   wp_get_attachment_image() to get the HTML image.
 * @uses   get_children() to get the attached images if no [gallery] found in the post content.
 * @return string
 */
function mymedic_get_format_gallery() {

	// Set up a default, empty $html variable.
	$html = '';

	// for has_sidebar
	$size = 'post-thumbnail';

	// for no sidebar
	if ( current_theme_supports( 'theme-layouts' ) && ! is_admin() ) {
		if ( 'layout-1c' == theme_layouts_get_layout() ) {
			$size = 'large';
		}
	}

	// opening wrapper
	$html = '<div id="myCarousel-' . get_the_ID() . '" class="carousel slide" data-ride="carousel">';

		$html .= '<div class="carousel-inner" role="listbox">';

	// Check the [gallery] shortcode in post content.
	$gallery = get_post_gallery( get_the_ID(), false );

	// Check if the [gallery] exist.
	if ( $gallery ) {

		// Check if the gallery ids exist.
		if ( isset( $gallery['ids'] ) ) {

			// Get the gallery ids and convert it into array.
			$ids = explode( ',', $gallery['ids'] );

			// Display the gallery in a cool slideshow on index page.
			foreach( $ids as $key => $id ) {
				$classes = ( 0 == $key ) ? 'item active' : 'item';
				$html .= '<div class="' . esc_attr( $classes ) . '">';
				$html .= wp_get_attachment_image( $id, $size, false, array( 'class' => 'img-responsive' ) );
				$html .= '</div>';
			}

		} else {

			// If gallery ids not exist, display the mymedic gallery markup.
			// avoid this, since it'll look bad
			// $html = get_post_gallery( get_the_ID() );

			// if gallery based on images attached to post (only [gallery] in post content)
			// note: in the post content, better to use: [gallery size="large"] or [gallery size="full"]
			$srcs = $gallery['src'];

			// Display the gallery in a cool slideshow on index page.
			foreach( $srcs as $key => $src ) {
				$classes = ( 0 == $key ) ? 'item active' : 'item';
				$html .= '<div class="' . esc_attr( $classes ) . '">';
				$html .= '<img src="' . esc_url( $src ) . '" class="img-responsive" />';
				$html .= '</div>';
			}

		}

	// If no [gallery] in post content, get attached images to the post.
	} else {

		// Set up default arguments.
		$defaults = array(
			'order'          => 'ASC',
			'post_type'      => 'attachment',
			'post_parent'    => get_the_ID(),
			'post_mime_type' => 'image',
			'numberposts'    => -1
		);

		// Retrieves attachments from the post.
		$attachments = get_children( apply_filters( 'mymedic_gallery_format_args', $defaults ) );

		// Check if attachments exist.
		if ( $attachments ) {

			// Display the attachment images in a cool slideshow on index page.
			foreach ( $attachments as $key => $attachment ) {
				$classes = ( 0 == $key ) ? 'item active' : 'item';
				$html .= '<div class="' . esc_attr( $classes ) . '">';
				$html .= wp_get_attachment_image( $attachment->ID, $size, false, array( 'class' => 'img-responsive' ) );
				$html .= '</div>';
			}

		} else {

			// if no [gallery] shortcode and has no attachments, bail them out
			return;

		}

	}

		$html .= '</div><!-- .carousel-inner -->';

		// control
		$html .= '<a class="left carousel-control" href="#myCarousel-' .get_the_ID() . '" role="button" data-slide="prev">';
			$html .= '<span class="fa fa-angle-left" aria-hidden="true"></span>';
			$html .= '<span class="sr-only">' . esc_html__( 'Previous', 'mymedic' ) . '</span>';
		$html .= '</a>';
		$html .= '<a class="right carousel-control" href="#myCarousel-' . get_the_ID() . '" role="button" data-slide="next">';
			$html .= '<span class="fa fa-angle-right" aria-hidden="true"></span>';
			$html .= '<span class="sr-only">' . esc_html__( 'Next', 'mymedic' ) . '</span>';
		$html .= '</a>';

	// closing wrapper
	$html .= '</div><!-- #myCarousel-## -->';

	// Return the gallery images.
	return $html;

}
endif;

if ( ! function_exists( 'mymedic_get_post_format_link_url' ) ) :
/**
 * Forked from hybrid_get_the_post_format_url.
 * Filters 'get_the_post_format_url' to make for a more robust and back-compatible function.  If WP did
 * not find a URL, check the post content for one.  If nothing is found, return the post permalink.
 * Used in Post Format Link
 *
 * @since 1.0.0
 */
function mymedic_get_post_format_link_url( $url = '', $post = null ) {

	if ( empty( $url ) ) {

		$post = is_null( $post ) ? get_post() : $post;

		/* Catch links that are not wrapped in an '<a>' tag. */
		$content_url = preg_match( '/<a\s[^>]*?href=[\'"](.+?)[\'"]/is', make_clickable( $post->post_content ), $matches );

		$content_url = ! empty( $matches[1] ) ? esc_url_raw( $matches[1] ) : '';

		$url = ! empty( $content_url ) ? $content_url : get_permalink( get_the_ID() );
	}

	return $url;
}
endif;

if ( ! function_exists( 'mymedic_format_audio' ) ) :
/**
 * Format audio
 *
 * @since  1.0.0
 */
function mymedic_format_audio() {

	// Get the metabox data
	$embed  = get_post_meta( get_the_ID(), 'tj_format_audio_embed', true );
	$upload = get_post_meta( get_the_ID(), 'tj_format_audio_upload', true );

	// Display the audio
	if ( $embed ) {
		echo wp_oembed_get( $embed );
	} elseif ( $upload ) {
		// Get the audio url/
		$url = wp_get_attachment_url( $upload );

		// Display the audio.
		echo do_shortcode( '[audio width="1050" src="' . $url . '"]' );
	} else {
		// fallback to audio in content
		echo hybrid_media_grabber( array( 'type' => 'audio', 'split_media' => true ) );
	}

}
endif;

if ( ! function_exists( 'mymedic_format_video' ) ) :
/**
 * Format video
 *
 * @since  1.0.0
 */
function mymedic_format_video() {

	// Get the metabox data
	$embed  = get_post_meta( get_the_ID(), 'tj_format_video_embed', true );
	$upload = get_post_meta( get_the_ID(), 'tj_format_video_upload', true );

	// Display the video
	if ( $embed ) {
		echo wp_oembed_get( $embed );
	} elseif ( $upload ) {
		// Get the video url/
		$url = wp_get_attachment_url( $upload );

		// Display the video.
		echo do_shortcode( '[video width="1050" src="' . $url . '"]' );
	} else {
		// fallback to video in content
		echo hybrid_media_grabber( array( 'type' => 'video', 'split_media' => true ) );
	}

}
endif;

if ( ! function_exists( 'mymedic_format_gallery' ) ) :
/**
 * Format gallery
 *
 * @since  1.0.0
 */
function mymedic_format_gallery() {

	// Get the metabox data
	$images = get_post_meta( get_the_ID(), 'tj_format_gallery', true );

	// Display the gallery
	if ( $images ) { ?>
		<div id="myCarousel-<?php the_ID(); ?>" class="carousel slide" data-ride="carousel">
			<div class="carousel-inner" role="listbox">
			<?php
				foreach( $images as $key => $image ):
					$classes = ( 0 == $key ) ? 'item active' : 'item';
					echo '<div class="' . esc_attr( $classes ) . '">';
						echo wp_get_attachment_image( $image, 'post-thumbnail', false, array( 'class' => 'img-responsive' ) );
					echo '</div>';
				endforeach;
			?>
				<a class="left carousel-control" href="#myCarousel-<?php the_ID(); ?>" role="button" data-slide="prev">
					<span class="fa fa-angle-left" aria-hidden="true"></span>
					<span class="sr-only"><?php esc_html_e( 'Previous', 'mymedic' ); ?></span>
				</a>
				<a class="right carousel-control" href="#myCarousel-<?php the_ID(); ?>" role="button" data-slide="next">
					<span class="fa fa-angle-right" aria-hidden="true"></span>
					<span class="sr-only"><?php esc_html_e( 'Next', 'mymedic' ); ?></span>
				</a>
			</div>
		</div>
		<?php
	} else {
		echo mymedic_get_format_gallery();
	}

}
endif;

if ( ! function_exists( 'mymedic_format_image' ) ) :
/**
 * Format gallery
 *
 * @since  1.0.0
 */
function mymedic_format_image( $first = true ) {
	// Get the metabox data
	$image = get_post_meta( get_the_ID(), 'tj_format_image_upload', true );

	// let's assume post-thumbnail size is enough
	$size = 'post-thumbnail';

	// check if metabox has value
	if ( $image ) {
		$attr['class'] = "attachment-$size size-$size img-responsive";
		// display the image
		echo wp_get_attachment_image( $image, 'large', false, $attr );
	} else if ( $first ) {
		// fallback to first image in content
		echo mymedic_get_first_image( $size, false );
	}
}
endif;

if ( ! function_exists( 'mymedic_format_link' ) ) :
/**
 * Format gallery
 *
 * @since  1.0.0
 */
function mymedic_format_link() {
	// Get the metabox data
	$url = get_post_meta( get_the_ID(), 'tj_format_link_url', true );

	// check if metabox has value
	if ( ! $url ) {
		// fallback to first link in content
		$url = mymedic_get_post_format_link_url();
	}
	?>
		<h2 class="entry-title" <?php hybrid_attr( 'entry-title' ); ?>>
			<a href="<?php echo esc_url( $url ); ?>" target="_blank">
				<?php if ( get_the_title() && ( __( '(Untitled)', 'mymedic' ) != get_the_title() ) ) { ?>
					<?php the_title(); ?>
				<?php } else { ?>
					<?php echo esc_attr( $url ); ?>
				<?php }	?>
			</a>
		</h2>
	<?php
}
endif;

if ( ! function_exists( 'mymedic_footer_text' ) ) :
/**
 * Footer Text
 *
 * @since  1.0.0
 */
function mymedic_footer_text() {

	// Get the customizer data
	$footer_text = mymedic_mod( PREFIX . 'footer-text' );

	// Polylang integration
	if ( is_polylang_activated() ) {
		$footer_text = pll__( mymedic_mod( PREFIX . 'footer-text' ) );
	}

	// Display the data
	echo '<p class="copyright">' . stripslashes( $footer_text ) . '</p>';

}
endif;

if ( ! function_exists( 'mymedic_header_image' ) ) :
/**
 * Header Image
 *
 * @since  1.0.0
 */
function mymedic_header_image() {

	// bail out
	if ( is_page_template( 'page-templates/block.php' ) || is_404() ) {
		if ( ! get_post_meta( get_the_ID(), 'tj_header_image_enable', true ) )
			return;
	}

	// check page to determine which default image should be called
	switch ( get_post_type() ) {
		case 'department':
			$default = PREFIX . 'header-department';
			break;

		case 'doctor':
			$default = PREFIX . 'header-doctor';
			break;

		case 'jetpack-portfolio':
			$default = PREFIX . 'header-portfolio';
			break;

		case 'post':
		case 'page':
		default:
			$default = PREFIX . 'header-image';
			break;
	}

	$image = mymedic_mod( $default );
	// var_dump( $image );

	// set default image
	// check if return int(0), fallback to default image
	$url = ( 0 != $image ) ? $image : customizer_library_get_default( $default ) ;
	$width = 1688;
	$height = 470;

	// check if there is custom image in single Post/Page
	if ( is_singular() ) {
		$image_singular = get_post_meta( get_the_ID(), 'tj_header_image', true );
		// replace default image with custom image id
		$image = ( $image_singular ) ? $image_singular : $image;
	}

	// if it's int
	if ( is_numeric( $image ) ) {
		// get $image array based on attachment_id
		$image = wp_get_attachment_image_src( $image, 'full' );
		// if has value, replace default values
		if ( $image ) {
			$url = $image[0];
			$width = $image[1];
			$height = $image[2];
		}
	}

	if ( $url ) :
	?>
	<section class="section banner" style="background-image:url('<?php echo esc_url( $url ); ?>');" data-img-width="<?php echo esc_attr( $width ); ?>" data-img-height="<?php echo esc_attr( $height ); ?>" data-diff="100">
	</section><!-- end section -->
	<?php
	endif;
}
endif;

if ( ! function_exists( 'mymedic_footer_menu_fallback' ) ) :
/**
 * Fallback for Footer Menu
 */
function mymedic_footer_menu_fallback() {

	$output = '';

	// get page list
	$pages = wp_list_pages( 'title_li=&echo=0&depth=1' );

	if ( $pages ) :

		$output .= '<ul class="list-inline">';

		// turn into array for easier management
		$pages_arr = explode( "\n", $pages );

		// set maximum pages to 4, if total pages less than 4, then so be it
		$nbpages = ( 4 > count( $pages_arr ) ) ? count( $pages_arr ) : 4;

		for ( $i = 0; $i < $nbpages; $i++ ) {
			$output .= $pages_arr[$i];
		}

		$output .= '</ul>';

	endif;

	echo $output;

}
endif;

if ( ! function_exists( 'mymedic_bootstrap_pagination' ) ) :
/**
 * Bootstrap pagination
 * http://www.ordinarycoder.com/paginate_links-class-ul-li-bootstrap/
 * http://brinidesigner.com/wordpress-custom-pagination-for-bootstrap/
 */
function mymedic_bootstrap_pagination( $echo = true ) {
	global $wp_query;
	$big = 999999999;
	$pages = paginate_links(array(
		'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format'    => '?page=%#%',
		'current'   => max( 1, get_query_var( 'paged' ) ),
		'total'     => $wp_query->max_num_pages,
		'prev_next' => false,
		'type'      => 'array',
		'prev_next' => TRUE,
		'prev_text' => '&larr;',
		'next_text' => '&rarr;'
	));

	if ( is_array( $pages ) ) {
		$paged = ( get_query_var( 'paged' ) == 0 ) ? 1 : get_query_var( 'paged' );

		$pagination = '<ul class="pagination">';

		foreach ( $pages as $page ) {
			$pagination .= "<li>$page</li>";
		}

		$pagination .= '</ul>';

		if ( $echo ) {
			echo wp_kses_post( $pagination );
		} else {
			return $pagination;
		}
	}
}
endif;

if ( ! function_exists( 'mymedic_content_class' ) ) :
/**
 * Print classes for #content based on Layout settings
 *
 * @since  1.0.0
 */
function mymedic_content_class() {

	$layout = theme_layouts_get_layout();

	switch ( $layout ) {
		// full width wide
		case 'layout-1c':
			$classes = '';
			break;

		// full width narrow
		case 'layout-1c-n':
			$classes = 'col-md-10 col-md-offset-1 col-sm-12 col-xs-12';
			break;

		// sidebar left
		case 'layout-2c-r':
			$classes = 'col-md-8 col-sm-12 col-xs-12 pull-right';
			break;

		// sidebar right
		case 'layout-2c-l':
		default:
			$classes = 'col-md-8 col-sm-12 col-xs-12';
			break;
	}

	echo 'class="' . esc_attr( $classes ) . '"';
}
endif;

if ( ! function_exists( 'mymedic_blog_wrapper_class' ) ) :
/**
 * Print classes for blog-wrapper based on Layout settings
 *
 * @since  1.0.0
 */
function mymedic_blog_wrapper_class() {

	global $wp_query;

	// grid layout
	if ( 'grid' == mymedic_mod( PREFIX . 'archive-layout' ) ) {

		// full width wide (3 cols)
		if ( in_array( get_theme_mod( 'theme_layout' ), array( '1c' ) ) ) {

			$classes = 'col-md-4 col-sm-6';

			// first: 0, 3, 6, ...
			if ( 0 === ( $wp_query->current_post % 3 ) ) {
				$classes .= ' first';
			}
			// last: 2, 5, 8, ...
			if ( 0 == ( ( $wp_query->current_post + 1 ) % 3 ) ) {
				$classes .= ' last';
			}

		} else {

			// left/right sidebar and full width narrow (2 cols)
			$classes = 'col-md-6 col-sm-6';

			// first: 0, 2, 4, ...
			if ( 0 === ( $wp_query->current_post % 2 ) ) {
				$classes .= ' first';
			}
			// last: 1, 3, 5, ...
			if ( 0 === ( $wp_query->current_post % 2 ) ) {
				$classes .= ' last';
			}

		}

	} else {

		// standard layout
		$classes = 'col-md-12';
	}

	echo 'class="' . esc_attr( $classes ) . '"';
}
endif;

if ( ! function_exists( 'mymedic_grid_wrapper_class' ) ) :
/**
 * Print classes for Medical Archive (Doctors and Departments)
 *
 * @since  1.0.0
 */
function mymedic_grid_wrapper_class() {

	global $wp_query;

	$classes = 'col-md-4 col-sm-6';

	// first: 0, 3, 6, ...
	if ( 0 === ( $wp_query->current_post % 3 ) ) {
		$classes .= ' first';
	}
	// last: 2, 5, 8, ...
	if ( 0 == ( ( $wp_query->current_post + 1 ) % 3 ) ) {
		$classes .= ' last';
	}

	echo 'class="' . esc_attr( $classes ) . '"';
}
endif;

if ( ! function_exists( 'mymedic_entry_taxonomy' ) ) :
/**
 * Print Taxonomy based on current Post Type
 */
function mymedic_entry_taxonomy() {

	// assign Tax based on Post Type
	if ( 'doctor' == get_post_type() ) {
		$tax = 'speciality';
	} elseif ( 'jetpack-portfolio' == get_post_type() ) {
		$tax = 'jetpack-portfolio-type';
	} else {
		return;
	}

	$tax = get_the_terms( get_the_ID(), $tax );

	if ( $tax ) {
		?>
		<span class="entry-category" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
			<a class="category_title" href="<?php echo esc_url( get_category_link( $tax[0]->term_id ) ); ?>"><?php echo esc_html( $tax[0]->name ); ?></a>
		</span><!-- .entry-category -->
		<?php
	}
}
endif;

if ( ! function_exists( 'mymedic_doctor_skills' ) ) :
/**
 * Print Doctor Skills
 */
function mymedic_doctor_skills() {

	// bail out for precaution
	if ( 'doctor' != get_post_type() )
		return;

	$skills = get_post_meta( get_the_ID(), 'tj_doctor_skill', true );

	// return nothing if the Doctor has no skills
	if ( ! $skills )
		return;
	?>
	<?php
		for ( $i = 0; $i < $skills; $i++ ) :
			$name = get_post_meta( get_the_ID(), 'tj_doctor_skill_' . $i . '_name', true );
			$value = get_post_meta( get_the_ID(), 'tj_doctor_skill_' . $i . '_rating', true );
	?>
		<p><?php echo esc_html( $name ); ?></p>
		<div class="progress">
			<div class="progress-bar" role="progressbar" data-transitiongoal="<?php echo esc_attr( $value ); ?>"><span><?php echo esc_html( $value ); ?></span></div>
		</div>
	<?php endfor;
}
endif;
