<?php
/**
 * Custom template tags used to integrate this theme with WooCommerce.
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'mymedic_header_cart' ) ) :
/**
 * Display Header Cart
 *
 * @since  1.0.0
 */
function mymedic_header_cart() {
	?>
		<div class="header-cart">
			<span>
				<?php mymedic_cart_link(); ?>
			</span>
			<?php the_widget( 'WC_Widget_Cart', 'title=' ); ?>
		</div>
	<?php
}
endif;

if ( ! function_exists( 'mymedic_cart_link' ) ) :
/**
 * Cart link
 *
 * @since  1.0.0
 */
function mymedic_cart_link() { ?>
	<a class="cart-contents" href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" title="<?php esc_attr_e( 'View your shopping cart', 'mymedic' ); ?>">
		<span class="total"><?php echo wp_kses_data( WC()->cart->get_cart_subtotal() ); ?></span>
		<i class="fa fa-shopping-cart"></i>
		<span class="count"><?php echo wp_kses_data( WC()->cart->get_cart_contents_count() );?></span>
	</a>
	<?php
}
endif;

if ( ! function_exists( 'mymedic_before_content' ) ) :
/**
 * Before Content
 * Wraps all WooCommerce content in wrappers which match the theme markup
 *
 * @since   1.0.0
 */
function mymedic_before_content() {
	?>
	<section class="section white">
		<div class="container">
		<?php
}
endif;

if ( ! function_exists( 'mymedic_after_content' ) ) :
/**
 * After Content
 * Closes the wrapping divs
 *
 * @since   1.0.0
 */
function mymedic_after_content() {
	?>
		</div><!-- .container -->
	</section><!-- .section -->

	<?php
}
endif;

if ( ! function_exists( 'mymedic_sorting_wrapper' ) ) :
/**
 * Sorting wrapper
 *
 * @since   1.0.0
 */
function mymedic_sorting_wrapper() {
	echo '<div class="shop-top clearfix">';
}
endif;

if ( ! function_exists( 'mymedic_sorting_wrapper_close' ) ) :
/**
 * Sorting wrapper close
 *
 * @since   1.0.0
 */
function mymedic_sorting_wrapper_close() {
	echo '</div>';
}
endif;

if ( ! function_exists( 'storefront_upsell_display' ) ) :
/**
 * Upsells
 * Replace the default upsell function with our own which displays the correct number product columns
 *
 * @since   1.0.0
 */
function mymedic_upsell_display() {
	woocommerce_upsell_display( -1, 3 );
}
endif;

if ( ! function_exists( 'mymedic_add_to_wishlist' ) ) :
/**
 * Add to wishlist
 *
 * @since   1.0.0
 */
function mymedic_add_to_wishlist() {

	if ( class_exists( 'YITH_WCWL_Shortcode' ) ) {
		echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
	}

}
endif;

if ( ! function_exists( 'mymedic_woocommerce_result_count_wrapper_start' ) ) :
/**
 * Result count Wrapper start
 */
function mymedic_woocommerce_result_count_wrapper_start() {
	echo '<div class="title-area pull-left">';
}
endif;

if ( ! function_exists( 'mymedic_woocommerce_result_count_wrapper_end' ) ) :
/**
 * Result count Wrapper end
 */
function mymedic_woocommerce_result_count_wrapper_end() {
	echo '</div>';
}
endif;

if ( ! function_exists( 'mymedic_woocommerce_ordering_wrapper_start' ) ) :
/**
 * Result count Wrapper start
 */
function mymedic_woocommerce_ordering_wrapper_start() {
	echo '<div class="pull-right hidden-xs">';
}
endif;

if ( ! function_exists( 'mymedic_woocommerce_ordering_wrapper_end' ) ) :
/**
 * Result count Wrapper end
 */
function mymedic_woocommerce_ordering_wrapper_end() {
	echo '</div>';
}
endif;
