<?php
/**
 * The Template for displaying Page Title and Breadcrumb
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( is_page_template( 'page-templates/block.php' ) ) {
	if ( ! get_post_meta( get_the_ID(), 'tj_page_subtitle_enable', true ) )
		return;
}

// set default title; used for Blog and Single Post
$page_title = mymedic_mod( PREFIX . 'default-title' );
// set default subtitle/description; used for Blog, Single Post and Single Page
$page_desc = mymedic_mod( PREFIX . 'default-desc' );

// custom Blog Title
$posts_page = get_option( 'page_for_posts' );
if ( ! empty( $posts_page ) && is_numeric( $posts_page ) ) {
	$page_title = get_the_title( $posts_page );
}

// Department
if ( 'department' == get_post_type() ) {
	$page_title = mymedic_mod( PREFIX . 'department-title' );
	$page_desc = mymedic_mod( PREFIX . 'department-desc' );
}

// Doctor
if ( 'doctor' == get_post_type() ) {
	$page_title = mymedic_mod( PREFIX . 'doctor-title' );
	$page_desc = mymedic_mod( PREFIX . 'doctor-desc' );
}

// Portfolio
if ( 'jetpack-portfolio' == get_post_type() ) {
	$page_title = mymedic_mod( PREFIX . 'portfolio-title' );
	$page_desc = mymedic_mod( PREFIX . 'portfolio-desc' );
}

// Testimonial
if ( 'jetpack-testimonial' == get_post_type() ) {
	$page_title = mymedic_mod( PREFIX . 'testimonial-title' );
	$page_desc = mymedic_mod( PREFIX . 'testimonial-desc' );
}

// Service
if ( 'service' == get_post_type() ) {
	$page_title = mymedic_mod( PREFIX . 'service-title' );
	$page_desc = mymedic_mod( PREFIX . 'service-desc' );
}

// Polylang integration
if ( is_polylang_activated() ) {
	$page_title = pll__( mymedic_mod( PREFIX . 'default-title' ) );
	$page_desc  = pll__( mymedic_mod( PREFIX . 'default-desc' ) );

	if ( 'department' == get_post_type() ) {
		$page_title = pll__( mymedic_mod( PREFIX . 'department-title' ) );
		$page_desc = pll__( mymedic_mod( PREFIX . 'department-desc' ) );
	}
	if ( 'doctor' == get_post_type() ) {
		$page_title = pll__( mymedic_mod( PREFIX . 'doctor-title' ) );
		$page_desc = pll__( mymedic_mod( PREFIX . 'doctor-desc' ) );
	}
	if ( 'jetpack-portfolio' == get_post_type() ) {
		$page_title = pll__( mymedic_mod( PREFIX . 'portfolio-title' ) );
		$page_desc = pll__( mymedic_mod( PREFIX . 'portfolio-desc' ) );
	}
	if ( 'jetpack-testimonial' == get_post_type() ) {
		$page_title = pll__( mymedic_mod( PREFIX . 'testimonial-title' ) );
		$page_desc = pll__( mymedic_mod( PREFIX . 'testimonial-desc' ) );
	}
	if ( 'service' == get_post_type() ) {
		$page_title = pll__( mymedic_mod( PREFIX . 'service-title' ) );
		$page_desc = pll__( mymedic_mod( PREFIX . 'service-desc' ) );
	}
}

// custom subtitle for Singular (Post, Page, etc.)
if ( is_singular() ) {
	$description = get_post_meta( get_the_ID(), 'tj_page_subtitle', true );
	if ( $description )
		$page_desc = $description;
}
?>

<div class="page-title grey">
	<div class="container">
		<div class="title-area text-center">

			<h2>

				<?php if ( is_404() ) { ?>

					<?php _e( 'Page Not Found', 'mymedic' ); ?>
					<small><?php echo esc_html__( "Sorry, we can't find the page you are looking for.", 'mymedic' ); ?></small>

				<?php } elseif ( is_home() ) { ?>

					<?php echo wp_kses_post( $page_title ); ?>
					<small><?php echo wp_kses_post( $page_desc ); ?></small>

				<?php } elseif ( is_category() ) { ?>

					<?php the_archive_title( '', '' ); ?>
					<small><?php echo category_description(); ?></small>

				<?php } elseif ( is_tag() ) { ?>

					<?php the_archive_title( '', '' ); ?>
					<small><?php echo tag_description(); ?></small>

				<?php } elseif ( is_tax() ) { ?>

					<?php single_term_title(); ?>
					<?php $desc = term_description( '', get_query_var( 'taxonomy' ) ); ?>
					<small><?php echo ( $desc ) ? $desc : $page_desc; ?></small>

				<?php } elseif ( is_author() ) { ?>

					<?php the_archive_title( '', '' ); ?>
					<small><?php echo wp_kses_post( get_the_author_meta( 'description', get_query_var( 'author' ) ) ); ?></small>

				<?php } elseif ( is_search() ) { ?>

					<?php printf( __( 'Search Results for: %s', 'mymedic' ), '<span>' . get_search_query() . '</span>' ); ?>
					<small><?php echo sprintf( __( 'You are browsing the search results for "%s"', 'mymedic' ), esc_attr( get_search_query() ) ); ?></small>

				<?php } elseif ( is_post_type_archive() ) { ?>

					<?php $post_type = get_post_type_object( get_query_var( 'post_type' ) ); ?>
					<?php
					if ( is_post_type_archive( 'product' ) ) {
						woocommerce_page_title();
					} else {
						// check if set from Customizer
						if ( $page_title ) {
							echo wp_kses_post( $page_title );
						} else {
							// if not, throwback to Post Type default name
							post_type_archive_title();
						}
					}
					?>
					<small>
						<?php
						if ( is_post_type_archive( 'product' ) ) {
							do_action( 'woocommerce_archive_description' );
						// check if set from Customzier
						} elseif ( $page_desc ) {
							echo wp_kses_post( $page_desc );
						// if not throwback to Post Type default description
						} elseif ( !empty( $post_type->description ) ) {
							echo wp_kses_post( $post_type->description );
						}
						?>
					</small>

				<?php } elseif ( is_day() || is_month() || is_year() ) { ?>

					<?php
						if ( is_day() )
							$date = get_the_time( __( 'F d, Y', 'mymedic' ) );
						elseif ( is_month() )
							$date = get_the_time( __( 'F Y', 'mymedic' ) );
						elseif ( is_year() )
							$date = get_the_time( __( 'Y', 'mymedic' ) );

						the_archive_title();
					?>
					<small><?php echo sprintf( __( 'You are browsing the site archives for %s.', 'mymedic' ), $date ); ?></small>

				<?php } elseif ( is_archive() ) { ?>

					<?php
						the_archive_title( '', '' );
						the_archive_description( '<small>', '</small>' );
					?>

				<?php } elseif ( is_singular( 'department' ) || is_singular( 'doctor' ) || is_singular( 'service' )
					|| is_singular( 'jetpack-testimonial' ) ) { ?>

					<?php single_post_title(); ?>
					<small><?php echo wp_kses_post( $page_desc ); ?></small>

				<?php } elseif ( is_page() ) { ?>

					<?php
					// Get the customizer value.
					$title = mymedic_mod( PREFIX . 'page-title' );
					if ( $title ) :
					?>
						<span <?php hybrid_attr( 'entry-title' ); ?>><?php single_post_title(); ?></span>
						<small><?php echo wp_kses_post( $page_desc ); ?></small>
					<?php endif; ?>

				<?php } elseif ( is_single() ) { ?>

					<?php echo wp_kses_post( $page_title ); ?>
					<small><?php echo wp_kses_post( $page_desc ); ?></small>

				<?php } // End if check ?>

			</h2>

			<div class="bread">
				<?php breadcrumb_trail( array(
					'show_on_front'   => false,
					'show_title'      => true, // needed for Single Page
					'show_browse'     => false
				)); ?>
			</div><!-- end bread -->

		</div><!-- end title-area -->
	</div><!-- .container -->
</div><!-- end page-title -->
